@@ -4,23 +4,23 @@
 
 use std::collections::HashMap;
 
-use crate::aliases::WinResult;
+use crate::aliases::{HrResult, WinResult};
 use crate::co;
 use crate::ffi::{
 	advapi32,
 	BOOL,
 	comctl32,
 	comdlg32,
-	HRESULT,
 	kernel32,
 	shell32,
 	user32,
 	version,
 };
 use crate::handles::{HINSTANCE, HLOCAL, HWND};
+use crate::msg::MsgSend;
 use crate::privs::{
 	bool_to_winresult,
-	hr_to_winresult,
+	ok_to_hrresult,
 	INVALID_FILE_ATTRIBUTES,
 	MAX_COMPUTERNAME_LENGTH,
 	MAX_PATH,
@@ -174,7 +174,7 @@ pub fn CloseClipboard() -> WinResult<()> {
 /// }
 /// ```
 pub fn CommandLineToArgv(cmd_line: &str) -> WinResult<Vec<String>> {
-	let mut num_args: i32 = 0;
+	let mut num_args = i32::default();
 	let lp_arr = unsafe {
 		shell32::CommandLineToArgvW(
 			WString::from_str(cmd_line).as_ptr(),
@@ -190,7 +190,7 @@ pub fn CommandLineToArgv(cmd_line: &str) -> WinResult<Vec<String>> {
 		strs.push(WString::from_wchars_nullt(*lp).to_string());
 	}
 
-	(HLOCAL { ptr: lp_arr as _ })
+	(HLOCAL(lp_arr as _))
 		.LocalFree()
 		.map(|_| strs)
 }
@@ -568,7 +568,7 @@ pub fn GetFileVersionInfo(file_name: &str) -> WinResult<Vec<u8>> {
 /// [`GetFileVersionInfoSize`](https://docs.microsoft.com/en-us/windows/win32/api/winver/nf-winver-getfileversioninfosizew)
 /// function.
 pub fn GetFileVersionInfoSize(file_name: &str) -> WinResult<u32> {
-	let mut dw_handle: u32 = 0;
+	let mut dw_handle = u32::default();
 	match unsafe {
 		version::GetFileVersionInfoSizeW(
 			WString::from_str(file_name).as_ptr(),
@@ -583,7 +583,7 @@ pub fn GetFileVersionInfoSize(file_name: &str) -> WinResult<u32> {
 /// [`GetFirmwareType`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-getfirmwaretype)
 /// function.
 pub fn GetFirmwareType() -> WinResult<co::FIRMWARE_TYPE> {
-	let mut ft: u32 = 0;
+	let mut ft = u32::default();
 	bool_to_winresult(unsafe { kernel32::GetFirmwareType(&mut ft) })
 		.map(|_| co::FIRMWARE_TYPE(ft))
 }
@@ -666,7 +666,7 @@ pub fn GetMessage(
 	match unsafe {
 		user32::GetMessageW(
 			msg as *mut _ as _,
-			hwnd.map_or(std::ptr::null_mut(), |h| h.ptr),
+			hwnd.map_or(std::ptr::null_mut(), |h| h.0),
 			msg_filter_min, msg_filter_max,
 		)
 	} {
@@ -822,18 +822,24 @@ pub const fn HIWORD(v: u32) -> u16 {
 	(v >> 16 & 0xffff) as _
 }
 
-/// [`HRESULT_FROM_WIN32`](https://docs.microsoft.com/en-us/windows/win32/api/winerror/nf-winerror-hresult_from_win32)
-/// function. Originally a macro.
-pub const fn HRESULT_FROM_WIN32(hr: HRESULT) -> co::ERROR {
-	co::ERROR((hr as u32) & 0xffff)
-}
-
 /// [`InitCommonControls`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-initcommoncontrols)
 /// function.
 pub fn InitCommonControls() {
 	unsafe { comctl32::InitCommonControls() }
 }
 
+/// [`InSendMessage`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-insendmessage)
+/// function.
+pub fn InSendMessage() -> bool {
+	unsafe { user32::InSendMessage() != 0 }
+}
+
+/// [`InSendMessageEx`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-insendmessageex)
+/// function.
+pub fn InSendMessageEx() -> co::ISMEX {
+	co::ISMEX(unsafe { user32::InSendMessageEx()})
+}
+
 /// [`IsGUIThread`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-isguithread)
 /// function.
 pub fn IsGUIThread(convert_to_gui_thread: bool) -> WinResult<bool> {
@@ -1077,7 +1083,7 @@ pub fn PeekMessage(
 	unsafe {
 		user32::PeekMessageW(
 			msg as *mut _ as _,
-			hwnd.map_or(std::ptr::null_mut(), |h| h.ptr),
+			hwnd.map_or(std::ptr::null_mut(), |h| h.0),
 			msg_filter_min,
 			msg_filter_max,
 			remove_msg.0,
@@ -1091,6 +1097,20 @@ pub fn PostQuitMessage(exit_code: i32) {
 	unsafe { user32::PostQuitMessage(exit_code) }
 }
 
+/// [`PostThreadMessage`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-postthreadmessagew)
+/// function.
+pub fn PostThreadMessage<M: MsgSend>(thread_id: u32, msg: M) -> WinResult<()> {
+	let mut msg = msg;
+	let wm_any = msg.as_generic_wm();
+	bool_to_winresult(
+		unsafe {
+			user32::PostThreadMessageW(
+				thread_id, wm_any.msg_id.0, wm_any.wparam, wm_any.lparam,
+			)
+		}
+	)
+}
+
 /// [`QueryPerformanceCounter`](https://docs.microsoft.com/en-us/windows/win32/api/profileapi/nf-profileapi-queryperformancecounter)
 /// function.
 ///
@@ -1110,7 +1130,7 @@ pub fn PostQuitMessage(exit_code: i32) {
 /// println!("Operation lasted {:.2} ms", duration_ms);
 /// ```
 pub fn QueryPerformanceCounter() -> WinResult<i64> {
-	let mut perf_count: i64 = 0;
+	let mut perf_count = i64::default();
 	bool_to_winresult(
 		unsafe { kernel32::QueryPerformanceCounter(&mut perf_count) },
 	).map(|_| perf_count)
@@ -1119,7 +1139,7 @@ pub fn QueryPerformanceCounter() -> WinResult<i64> {
 /// [`QueryPerformanceFrequency`](https://docs.microsoft.com/en-us/windows/win32/api/profileapi/nf-profileapi-queryperformancecounter)
 /// function.
 pub fn QueryPerformanceFrequency() -> WinResult<i64> {
-	let mut freq: i64 = 0;
+	let mut freq = i64::default();
 	bool_to_winresult(
 		unsafe { kernel32::QueryPerformanceFrequency(&mut freq) },
 	).map(|_| freq)
@@ -1285,7 +1305,7 @@ pub fn SoundSentry() -> bool {
 /// [`SystemParametersInfo`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-systemparametersinfow)
 /// function.
 ///
-/// **Note:** The `pvParam` type varies according to `uiAction`. If you set it
+/// **Note:** The `pv_param` type varies according to `action`. If you set it
 /// wrong, you're likely to cause a buffer overrun.
 pub unsafe fn SystemParametersInfo<T>(
 	action: co::SPI,
@@ -1351,9 +1371,9 @@ pub fn SystemTimeToTzSpecificLocalTime(
 /// # Examples
 ///
 /// ```rust,ignore
-/// use winsafe::{co, gui, IconIdTdicon,
-///     TASKDIALOG_BUTTON TASKDIALOGCONFIG, TaskDialogIndirect,
-///     WString};
+/// use winsafe::{co, gui, IconIdTdicon};
+/// use winsafe::{TASKDIALOG_BUTTON TASKDIALOGCONFIG, TaskDialogIndirect};
+/// use winsafe::WString;
 ///
 /// let wnd: gui::WindowMain; // initialized somewhere
 ///
@@ -1383,13 +1403,13 @@ pub fn SystemTimeToTzSpecificLocalTime(
 /// ```
 pub fn TaskDialogIndirect(
 	task_config: &TASKDIALOGCONFIG,
-	verification_flag_checked: Option<&mut bool>) -> WinResult<(co::DLGID, u16)>
+	verification_flag_checked: Option<&mut bool>) -> HrResult<(co::DLGID, u16)>
 {
-	let mut pn_button: i32 = 0;
-	let mut pn_radio_button: i32 = 0;
+	let mut pn_button = i32::default();
+	let mut pn_radio_button = i32::default();
 	let mut pf_bool: BOOL = 0;
 
-	hr_to_winresult(
+	ok_to_hrresult(
 		unsafe {
 			comctl32::TaskDialogIndirect(
 				task_config as *const _ as _,
@@ -1428,7 +1448,7 @@ pub fn UnregisterClass(class_name: &str, hinst: HINSTANCE) -> WinResult<()> {
 		unsafe {
 			user32::UnregisterClassW(
 				WString::from_str(class_name).as_ptr(),
-				hinst.ptr,
+				hinst.0,
 			)
 		},
 	)
