@@ -1,5 +1,6 @@
-use crate::aliases::BoxResult;
 use crate::co;
+use crate::gui::base::Base;
+use crate::gui::events::base_events_proxy::BaseEventsProxy;
 use crate::structs::{
 	NMDATETIMECHANGE,
 	NMDATETIMEFORMAT,
@@ -8,21 +9,23 @@ use crate::structs::{
 	NMDATETIMEWMKEYDOWN,
 };
 
-pub_struct_ctrl_events_proxy! {
-	/// Exposes date and time picker control
-	/// [notifications](https://docs.microsoft.com/en-us/windows/win32/controls/bumper-date-and-time-picker-control-reference-notifications).
-	///
-	/// These event methods are just proxies to the
-	/// [`WindowEvents`](crate::gui::events::WindowEvents) of the parent window,
-	/// who is the real responsible for the child event handling.
-	///
-	/// You cannot directly instantiate this object, it is created internally by
-	/// the control.
-	DateTimePickerEvents
-}
+/// Exposes date and time picker control
+/// [notifications](https://docs.microsoft.com/en-us/windows/win32/controls/bumper-date-and-time-picker-control-reference-notifications).
+///
+/// These event methods are just proxies to the
+/// [`WindowEvents`](crate::gui::events::WindowEvents) of the parent window, who
+/// is the real responsible for the child event handling.
+///
+/// You cannot directly instantiate this object, it is created internally by the
+/// control.
+pub struct DateTimePickerEvents(BaseEventsProxy);
 
 impl DateTimePickerEvents {
-	pub_fn_nfy_ret0! { dtn_close_up, co::DTN::CLOSEUP.into(),
+	pub(in crate::gui) fn new(parent_base: &Base, ctrl_id: u16) -> Self {
+		Self(BaseEventsProxy::new(parent_base, ctrl_id))
+	}
+
+	pub_fn_nfy_ret0! { dtn_close_up, co::DTN::CLOSEUP,
 		/// [`DTN_CLOSEUP`](https://docs.microsoft.com/en-us/windows/win32/controls/dtn-closeup)
 		/// notification.
 		///
@@ -32,14 +35,14 @@ impl DateTimePickerEvents {
 		/// while the calendar is open.
 	}
 
-	pub_fn_nfy_ret0_param! { dtn_date_time_change, co::DTN::DATETIMECHANGE.into(), NMDATETIMECHANGE,
+	pub_fn_nfy_ret0_param! { dtn_date_time_change, co::DTN::DATETIMECHANGE, NMDATETIMECHANGE,
 		/// [`DTN_DATETIMECHANGE`](https://docs.microsoft.com/en-us/windows/win32/controls/dtn-datetimechange)
 		/// notification.
 		///
 		/// Sent by a date and time picker control whenever a change occurs.
 	}
 
-	pub_fn_nfy_ret0! { dtn_drop_down, co::DTN::DROPDOWN.into(),
+	pub_fn_nfy_ret0! { dtn_drop_down, co::DTN::DROPDOWN,
 		/// [`DTN_DROPDOWN`](https://docs.microsoft.com/en-us/windows/win32/controls/dtn-dropdown)
 		/// notification.
 		///
@@ -47,7 +50,7 @@ impl DateTimePickerEvents {
 		/// drop-down month calendar.
 	}
 
-	pub_fn_nfy_ret0_mutparam! { dtn_format, co::DTN::FORMAT.into(), NMDATETIMEFORMAT,
+	pub_fn_nfy_ret0_mutparam! { dtn_format, co::DTN::FORMAT, NMDATETIMEFORMAT,
 		/// [`DTN_FORMAT`](https://docs.microsoft.com/en-us/windows/win32/controls/dtn-format)
 		/// notification.
 		///
@@ -55,7 +58,7 @@ impl DateTimePickerEvents {
 		/// displayed in a callback field.
 	}
 
-	pub_fn_nfy_ret0_mutparam! { dtn_format_query, co::DTN::FORMATQUERY.into(), NMDATETIMEFORMATQUERY,
+	pub_fn_nfy_ret0_mutparam! { dtn_format_query, co::DTN::FORMATQUERY, NMDATETIMEFORMATQUERY,
 		/// [`DTN_FORMATQUERY`](https://docs.microsoft.com/en-us/windows/win32/controls/dtn-formatquery)
 		/// notification.
 		///
@@ -64,7 +67,7 @@ impl DateTimePickerEvents {
 		/// field.
 	}
 
-	pub_fn_nfy_ret0_mutparam! { dtn_user_string, co::DTN::USERSTRING.into(), NMDATETIMESTRING,
+	pub_fn_nfy_ret0_mutparam! { dtn_user_string, co::DTN::USERSTRING, NMDATETIMESTRING,
 		/// [`DTN_USERSTRING`](https://docs.microsoft.com/en-us/windows/win32/controls/dtn-userstring)
 		/// notification.
 		///
@@ -74,7 +77,7 @@ impl DateTimePickerEvents {
 		/// [`DTS_APPCANPARSE`](crate::co::DTS::APPCANPARSE) style.
 	}
 
-	pub_fn_nfy_ret0_param! { dtn_wm_key_down, co::DTN::WMKEYDOWN.into(), NMDATETIMEWMKEYDOWN,
+	pub_fn_nfy_ret0_param! { dtn_wm_key_down, co::DTN::WMKEYDOWN, NMDATETIMEWMKEYDOWN,
 		/// [`DTN_WMKEYDOWN`](https://docs.microsoft.com/en-us/windows/win32/controls/dtn-wmkeydown)
 		/// notification.
 		///
