@@ -1,22 +1,25 @@
-use crate::aliases::BoxResult;
 use crate::co;
+use crate::gui::base::Base;
+use crate::gui::events::base_events_proxy::BaseEventsProxy;
 use crate::structs::{NMDAYSTATE, NMSELCHANGE, NMVIEWCHANGE};
 
-pub_struct_ctrl_events_proxy! {
-	/// Exposes month calendar control
-	/// [notifications](https://docs.microsoft.com/en-us/windows/win32/controls/bumper-month-calendar-control-reference-notifications).
-	///
-	/// These event methods are just proxies to the
-	/// [`WindowEvents`](crate::gui::events::WindowEvents) of the parent window,
-	/// who is the real responsible for the child event handling.
-	///
-	/// You cannot directly instantiate this object, it is created internally by
-	/// the control.
-	MonthCalendarEvents
-}
+/// Exposes month calendar control
+/// [notifications](https://docs.microsoft.com/en-us/windows/win32/controls/bumper-month-calendar-control-reference-notifications).
+///
+/// These event methods are just proxies to the
+/// [`WindowEvents`](crate::gui::events::WindowEvents) of the parent window, who
+/// is the real responsible for the child event handling.
+///
+/// You cannot directly instantiate this object, it is created internally by the
+/// control.
+pub struct MonthCalendarEvents(BaseEventsProxy);
 
 impl MonthCalendarEvents {
-	pub_fn_nfy_ret0_param! { mcn_get_day_state, co::MCN::GETDAYSTATE.into(), NMDAYSTATE,
+	pub(in crate::gui) fn new(parent_base: &Base, ctrl_id: u16) -> Self {
+		Self(BaseEventsProxy::new(parent_base, ctrl_id))
+	}
+
+	pub_fn_nfy_ret0_param! { mcn_get_day_state, co::MCN::GETDAYSTATE, NMDAYSTATE,
 		/// [`MCN_GETDAYSTATE`](https://docs.microsoft.com/en-us/windows/win32/controls/mcn-getdaystate)
 		/// notification.
 		///
@@ -26,7 +29,7 @@ impl MonthCalendarEvents {
 		/// [`MCS_DAYSTATE`](crate::co::MCS::DAYSTATE) style
 	}
 
-	pub_fn_nfy_ret0_param! { mcn_sel_change, co::MCN::SELCHANGE.into(), NMSELCHANGE,
+	pub_fn_nfy_ret0_param! { mcn_sel_change, co::MCN::SELCHANGE, NMSELCHANGE,
 		/// [`MCN_GETDAYSTATE`](https://docs.microsoft.com/en-us/windows/win32/controls/mcn-selchange)
 		/// notification.
 		///
@@ -34,7 +37,7 @@ impl MonthCalendarEvents {
 		/// range of dates changes.
 	}
 
-	pub_fn_nfy_ret0_param! { mcn_select, co::MCN::SELECT.into(), NMSELCHANGE,
+	pub_fn_nfy_ret0_param! { mcn_select, co::MCN::SELECT, NMSELCHANGE,
 		/// [`MCN_SELECT`](https://docs.microsoft.com/en-us/windows/win32/controls/mcn-select)
 		/// notification.
 		///
@@ -42,7 +45,7 @@ impl MonthCalendarEvents {
 		/// date selection within a month calendar control.
 	}
 
-	pub_fn_nfy_ret0_param! { mcn_view_change, co::MCN::VIEWCHANGE.into(), NMVIEWCHANGE,
+	pub_fn_nfy_ret0_param! { mcn_view_change, co::MCN::VIEWCHANGE, NMVIEWCHANGE,
 		/// [`MCN_VIEWCHANGE`](https://docs.microsoft.com/en-us/windows/win32/controls/mcn-viewchange)
 		/// notification.
 		///
