@@ -1,28 +1,31 @@
+use crate::gui::very_unsafe_cell::VeryUnsafeCell;
+
 /// Stores closures, associating them with an identifier.
-pub(in crate::gui) struct FuncStore<K, F> {
-	elems: Vec<(K, F)>,
+pub(in crate::gui) struct FuncStore<K: Copy + Eq, F> {
+	elems: VeryUnsafeCell<Vec<(K, F)>>,
 }
 
 impl<K: Copy + Eq, F> FuncStore<K, F> {
 	/// Creates a new, empty store.
-	pub fn new() -> FuncStore<K, F> {
+	pub(in crate::gui) fn new() -> FuncStore<K, F> {
 		Self {
-			elems: Vec::default(),
+			elems: VeryUnsafeCell::new(Vec::default()),
 		}
 	}
 
 	/// Inserts a new function into the store, associated to the given
 	/// identifier.
-	pub fn insert(&mut self, id: K, func: F) {
-		if self.elems.is_empty() {
-			self.elems.reserve(16); // arbitrary, prealloc for speed
+	pub(in crate::gui) fn insert(&self, id: K, func: F) {
+		let elems = self.elems.as_mut();
+		if elems.is_empty() {
+			elems.reserve(16); // arbitrary, prealloc for speed
 		}
-		self.elems.push((id, func));
+		elems.push((id, func));
 	}
 
 	/// Finds the last added function associated to the given identifier, if
 	/// any.
-	pub fn find(&self, id: K) -> Option<&F> {
+	pub(in crate::gui) fn find(&self, id: K) -> Option<&F> {
 		// Linear search, more performant for small collections.
 		// Searches backwards, so the function added last will be chosen.
 		self.elems.iter().rev()
@@ -32,7 +35,7 @@ impl<K: Copy + Eq, F> FuncStore<K, F> {
 
 	/// Finds all the functions associated to the given identifier, if any, and
 	/// returns an iterator to t
-	pub fn find_all(&self, id: K) -> impl Iterator<Item = &F> + '_ {
+	pub(in crate::gui) fn find_all(&self, id: K) -> impl Iterator<Item = &F> {
 		// https://depth-first.com/articles/2020/06/22/returning-rust-iterators
 		self.elems.iter()
 			.filter(move |elem| elem.0 == id)
@@ -40,7 +43,7 @@ impl<K: Copy + Eq, F> FuncStore<K, F> {
 	}
 
 	/// Tells whether no functions have been added.
-	pub fn is_empty(&self) -> bool {
+	pub(in crate::gui) fn is_empty(&self) -> bool {
 		self.elems.is_empty()
 	}
 }
