@@ -1,13 +1,9 @@
-//! Structs which expose the event methods of windows and controls.
-//!
-//! You cannot directly instantiate these objects, they are created internally
-//! by the controls.
+//! Events exposed by windows and controls, which allow the handling of native
+//! Windows messages.
 
-#[macro_use]
-mod macros;
-
-mod func_store;
+#[macro_use] mod macros;
 
+mod base_events_proxy;
 mod events_bn_rg;
 mod events_bn;
 mod events_cbn;
@@ -21,6 +17,8 @@ mod events_stn;
 mod events_trbn;
 mod events_tvn;
 mod events_wm;
+mod events_wm_nfy;
+mod func_store;
 
 pub use events_bn_rg::RadioGroupEvents;
 pub use events_bn::ButtonEvents;
@@ -34,5 +32,12 @@ pub use events_sbn::StatusBarEvents;
 pub use events_stn::LabelEvents;
 pub use events_trbn::TrackbarEvents;
 pub use events_tvn::TreeViewEvents;
+pub use events_wm_nfy::WindowEventsAll;
 pub use events_wm::WindowEvents;
-pub(crate) use events_wm::ProcessResult;
+pub(in crate::gui) use events_wm_nfy::sealed_events_wm_nfy;
+pub(in crate::gui) use events_wm::{ProcessResult, sealed_events_wm};
+
+pub(in crate::gui) mod prelude {
+	pub use super::events_wm::EventsView;
+	pub use super::events_wm_nfy::EventsViewAll;
+}
