@@ -6,11 +6,6 @@
 //! You'll probably want to start your GUI application using the
 //! [`WindowMain`](crate::gui::WindowMain).
 
-#[macro_use]
-mod macros;
-
-pub mod events;
-
 mod base;
 mod dlg_base;
 mod dlg_control;
@@ -23,18 +18,25 @@ mod raw_control;
 mod raw_main;
 mod raw_modal;
 mod resizer;
+mod traits_sealed;
 mod traits;
 mod very_unsafe_cell;
 mod window_control;
 mod window_main;
 mod window_modal;
 
+pub mod events;
+
 pub use native_controls::*;
 pub use raw_control::WindowControlOpts;
 pub use raw_main::WindowMainOpts;
 pub use raw_modal::WindowModalOpts;
-pub use resizer::{Resizer, Resz};
-pub use traits::{Child, Parent};
+pub use resizer::{Horz, Vert};
 pub use window_control::WindowControl;
 pub use window_main::WindowMain;
 pub use window_modal::WindowModal;
+
+pub(crate) mod prelude {
+	pub use super::events::prelude::*;
+	pub use super::traits::*;
+}
