@@ -1,8 +1,5 @@
 //! Native Win32 controls.
 
-#[macro_use]
-mod macros;
-
 mod base_native_control;
 mod button;
 mod check_box;
@@ -49,5 +46,5 @@ pub mod spec {
 	pub use super::list_view_columns::ListViewColumns;
 	pub use super::list_view_items::{ListViewItem, ListViewItems};
 	pub use super::status_bar_parts::StatusBarParts;
-	pub use super::tree_view_items::TreeViewItems;
+	pub use super::tree_view_items::{TreeViewItem, TreeViewItems};
 }
