@@ -5,7 +5,7 @@ use std::ops::Deref;
 ///
 /// **Extremely** unsafe, intended only to provide less verbose internal
 /// mutability within the `gui` module.
-pub(crate) struct VeryUnsafeCell<T>(UnsafeCell<T>);
+pub(in crate::gui) struct VeryUnsafeCell<T>(UnsafeCell<T>);
 
 unsafe impl<T> Send for VeryUnsafeCell<T> {}
 unsafe impl<T> Sync for VeryUnsafeCell<T> {}
@@ -19,12 +19,12 @@ impl<T> Deref for VeryUnsafeCell<T> {
 
 impl<T> VeryUnsafeCell<T> {
 	/// Instantiates a new object.
-	pub fn new(obj: T) -> VeryUnsafeCell<T> {
+	pub(in crate::gui) const fn new(obj: T) -> VeryUnsafeCell<T> {
 		Self(UnsafeCell::new(obj))
 	}
 
 	/// Returns a mutable reference to the underlying object.
-	pub fn as_mut(&self) -> &mut T {
+	pub(in crate::gui) fn as_mut(&self) -> &mut T {
 		unsafe { &mut *self.0.get() }
 	}
 }
