@@ -5,11 +5,13 @@ use crate::ffi::user32;
 use crate::funcs::GetLastError;
 use crate::structs::ACCEL;
 
-pub_struct_handle! {
-	/// Handle to an
-	/// [accelerator table](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#haccel).
-	HACCEL
-}
+/// Handle to an
+/// [accelerator table](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#haccel).
+#[repr(transparent)]
+#[derive(Copy, Clone, PartialEq, Eq)]
+pub struct HACCEL(pub(crate) *mut std::ffi::c_void);
+
+impl_handle!(HACCEL);
 
 impl HACCEL {
 	/// [`CreateAcceleratorTable`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-createacceleratortablew)
@@ -20,13 +22,13 @@ impl HACCEL {
 				accel.as_mut_ptr() as _,
 				accel.len() as _,
 			).as_mut()
-		}.map(|ptr| Self { ptr })
+		}.map(|ptr| Self(ptr))
 			.ok_or_else(|| GetLastError())
 	}
 
 	/// [`DestroyAcceleratorTable`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-destroyacceleratortable)
 	/// method.
 	pub fn DestroyAcceleratorTable(self) -> bool {
-		unsafe { user32::DestroyAcceleratorTable(self.ptr) != 0 }
+		unsafe { user32::DestroyAcceleratorTable(self.0) != 0 }
 	}
 }
