@@ -9,17 +9,19 @@ use crate::privs::{bool_to_winresult, CLR_INVALID, GDI_ERROR};
 use crate::structs::{COLORREF, POINT, RECT, SIZE, TEXTMETRIC};
 use crate::various::WString;
 
-pub_struct_handle! {
-	/// Handle to a
-	/// [device context](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#hdc).
-	HDC
-}
+/// Handle to a
+/// [device context](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#hdc).
+#[repr(transparent)]
+#[derive(Copy, Clone, PartialEq, Eq)]
+pub struct HDC(pub(crate) *mut std::ffi::c_void);
+
+impl_handle!(HDC);
 
 impl HDC {
 	/// [`AborthPath`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-abortpath)
 	/// method.
 	pub fn AbortPath(self) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::AbortPath(self.ptr) })
+		bool_to_winresult(unsafe { gdi32::AbortPath(self.0) })
 	}
 
 	/// [`AngleArc`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-anglearc)
@@ -31,7 +33,7 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				gdi32::AngleArc(
-					self.ptr,
+					self.0,
 					center.x, center.y,
 					radius, start_angle, sweep_angle,
 				)
@@ -42,7 +44,7 @@ impl HDC {
 	/// [`BeginPath`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-beginpath)
 	/// method.
 	pub fn BeginPath(self) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::BeginPath(self.ptr) })
+		bool_to_winresult(unsafe { gdi32::BeginPath(self.0) })
 	}
 
 	/// [`BitBlt`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-bitblt)
@@ -54,10 +56,10 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				gdi32::BitBlt(
-					self.ptr,
+					self.0,
 					dest_top_left.x, dest_top_left.y,
 					sz.cx, sz.cy,
-					hdc_src.ptr,
+					hdc_src.0,
 					src_top_left.x, src_top_left.y,
 					rop.0,
 				)
@@ -68,7 +70,7 @@ impl HDC {
 	/// [`CancelDC`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-canceldc)
 	/// method.
 	pub fn CancelDC(self) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::CancelDC(self.ptr) })
+		bool_to_winresult(unsafe { gdi32::CancelDC(self.0) })
 	}
 
 	/// [`Chord`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-chord)
@@ -79,7 +81,7 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				gdi32::Chord(
-					self.ptr,
+					self.0,
 					bounds.left, bounds.top, bounds.right, bounds.bottom,
 					start_radial.x, start_radial.y,
 					end_radial.x, end_radial.y,
@@ -92,10 +94,10 @@ impl HDC {
 	/// method.
 	///
 	/// **Note:** Must be paired with an
-	/// [`HBITMAP::DeleteObject`](crate::HBITMAP::DeleteObject) call.
+	/// [`HBITMAP::DeleteObject`](crate::prelude::HandleGdi::DeleteObject) call.
 	pub fn CreateCompatibleBitmap(self, cx: i32, cy: i32) -> WinResult<HBITMAP> {
-		unsafe { gdi32::CreateCompatibleBitmap(self.ptr, cx, cy).as_mut() }
-			.map(|ptr| HBITMAP { ptr })
+		unsafe { gdi32::CreateCompatibleBitmap(self.0, cx, cy).as_mut() }
+			.map(|ptr| HBITMAP(ptr))
 			.ok_or_else(|| GetLastError())
 	}
 
@@ -105,21 +107,21 @@ impl HDC {
 	/// **Note:** Must be paired with an [`HDC::DeleteDC`](crate::HDC::DeleteDC)
 	/// call.
 	pub fn CreateCompatibleDC(self) -> WinResult<HDC> {
-		unsafe { gdi32::CreateCompatibleDC(self.ptr).as_mut() }
-			.map(|ptr| Self { ptr })
+		unsafe { gdi32::CreateCompatibleDC(self.0).as_mut() }
+			.map(|ptr| Self(ptr))
 			.ok_or_else(|| GetLastError())
 	}
 
 	/// [`DeleteDC`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-deletedc)
 	/// method.
 	pub fn DeleteDC(self) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::DeleteDC(self.ptr) })
+		bool_to_winresult(unsafe { gdi32::DeleteDC(self.0) })
 	}
 
 	/// [`EndPath`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-endpath)
 	/// method.
 	pub fn EndPath(self) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::EndPath(self.ptr) })
+		bool_to_winresult(unsafe { gdi32::EndPath(self.0) })
 	}
 
 	/// [`EnumDisplayMonitors`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-enumdisplaymonitors)
@@ -144,7 +146,7 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				user32::EnumDisplayMonitors(
-					self.ptr,
+					self.0,
 					rc_clip.map_or(std::ptr::null_mut(), |rc| &rc as *const _ as _),
 					Self::enum_display_monitors_proc::<F> as _,
 					&func as *const _ as _,
@@ -163,14 +165,14 @@ impl HDC {
 	/// [`FillPath`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-fillpath)
 	/// method.
 	pub fn FillPath(self) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::FillPath(self.ptr) })
+		bool_to_winresult(unsafe { gdi32::FillPath(self.0) })
 	}
 
 	/// [`FillRect`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-fillrect)
 	/// method.
 	pub fn FillRect(self, rc: RECT, hbr: HBRUSH) -> WinResult<()> {
 		match unsafe {
-			gdi32::FillRect(self.ptr, &rc as *const _ as _, hbr.ptr)
+			gdi32::FillRect(self.0, &rc as *const _ as _, hbr.0)
 		} {
 			0 => Err(GetLastError()),
 			_ => Ok(()),
@@ -180,7 +182,7 @@ impl HDC {
 	/// [`GetDCBrushColor`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-getdcbrushcolor)
 	/// method.
 	pub fn GetDCBrushColor(self) -> WinResult<COLORREF> {
-		match unsafe { gdi32::GetDCBrushColor(self.ptr) } {
+		match unsafe { gdi32::GetDCBrushColor(self.0) } {
 			CLR_INVALID => Err(GetLastError()),
 			color => Ok(COLORREF(color)),
 		}
@@ -189,7 +191,7 @@ impl HDC {
 	/// [`GetDCPenColor`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-getdcpencolor)
 	/// method.
 	pub fn GetDCPenColor(self) -> WinResult<COLORREF> {
-		match unsafe { gdi32::GetDCPenColor(self.ptr) } {
+		match unsafe { gdi32::GetDCPenColor(self.0) } {
 			CLR_INVALID => Err(GetLastError()),
 			color => Ok(COLORREF(color)),
 		}
@@ -198,13 +200,13 @@ impl HDC {
 	/// [`GetDeviceCaps`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-getdevicecaps)
 	/// method.
 	pub fn GetDeviceCaps(self, index: co::GDC) -> i32 {
-		unsafe { gdi32::GetDeviceCaps(self.ptr, index.0) }
+		unsafe { gdi32::GetDeviceCaps(self.0, index.0) }
 	}
 
 	/// [`GetTextColor`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-gettextcolor)
 	/// method.
 	pub fn GetTextColor(self) -> WinResult<COLORREF> {
-		match unsafe { gdi32::GetTextColor(self.ptr) } {
+		match unsafe { gdi32::GetTextColor(self.0) } {
 			CLR_INVALID => Err(GetLastError()),
 			color => Ok(COLORREF(color)),
 		}
@@ -217,7 +219,7 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				gdi32::GetTextExtentPoint32W(
-					self.ptr,
+					self.0,
 					WString::from_str(text).as_ptr(),
 					text.chars().count() as _,
 					&mut sz as *mut _ as _,
@@ -230,14 +232,14 @@ impl HDC {
 	/// method.
 	pub fn GetTextMetrics(self, tm: &mut TEXTMETRIC) -> WinResult<()> {
 		bool_to_winresult(
-			unsafe { gdi32::GetTextMetricsW(self.ptr, tm as *mut _ as _) },
+			unsafe { gdi32::GetTextMetricsW(self.0, tm as *mut _ as _) },
 		)
 	}
 
 	/// [`LineTo`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-lineto)
 	/// method.
 	pub fn LineTo(self, x: i32, y: i32) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::LineTo(self.ptr, x, y) })
+		bool_to_winresult(unsafe { gdi32::LineTo(self.0, x, y) })
 	}
 
 	/// [`MoveToEx`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-movetoex)
@@ -248,7 +250,7 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				gdi32::MoveToEx(
-					self.ptr,
+					self.0,
 					x, y,
 					pt.map_or(std::ptr::null_mut(), |lp| lp as *mut _ as _),
 				)
@@ -263,7 +265,7 @@ impl HDC {
 	{
 		bool_to_winresult(
 			unsafe {
-				gdi32::PatBlt(self.ptr, top_left.x, top_left.y, sz.cx, sz.cy, rop.0)
+				gdi32::PatBlt(self.0, top_left.x, top_left.y, sz.cx, sz.cy, rop.0)
 			},
 		)
 	}
@@ -272,10 +274,10 @@ impl HDC {
 	/// method.
 	///
 	/// **Note:** Must be paired with an
-	/// [`HRGN::DeleteObject`](crate::HRGN::DeleteObject) call.
+	/// [`HRGN::DeleteObject`](crate::prelude::HandleGdi::DeleteObject) call.
 	pub fn PathToRegion(self) -> WinResult<HRGN> {
-		unsafe { gdi32::PathToRegion(self.ptr).as_mut() }
-			.map(|ptr| HRGN { ptr })
+		unsafe { gdi32::PathToRegion(self.0).as_mut() }
+			.map(|ptr| HRGN(ptr))
 			.ok_or_else(|| GetLastError())
 	}
 
@@ -287,7 +289,7 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				gdi32::Pie(
-					self.ptr,
+					self.0,
 					bounds.left, bounds.top, bounds.right, bounds.bottom,
 					radial_1.x, radial_1.y,
 					radial_2.y, radial_2.y,
@@ -301,11 +303,7 @@ impl HDC {
 	pub fn PolyBezier(self, pts: &[POINT]) -> WinResult<()> {
 		bool_to_winresult(
 			unsafe {
-				gdi32::PolyBezier(
-					self.ptr,
-					pts.as_ptr() as _,
-					pts.len() as _,
-				)
+				gdi32::PolyBezier(self.0, pts.as_ptr() as _, pts.len() as _)
 			},
 		)
 	}
@@ -315,11 +313,7 @@ impl HDC {
 	pub fn PolyBezierTo(self, pts: &[POINT]) -> WinResult<()> {
 		bool_to_winresult(
 			unsafe {
-				gdi32::PolyBezierTo(
-					self.ptr,
-					pts.as_ptr() as _,
-					pts.len() as _,
-				)
+				gdi32::PolyBezierTo(self.0, pts.as_ptr() as _, pts.len() as _)
 			},
 		)
 	}
@@ -328,13 +322,7 @@ impl HDC {
 	/// method.
 	pub fn Polyline(self, pts: &[POINT]) -> WinResult<()> {
 		bool_to_winresult(
-			unsafe {
-				gdi32::Polyline(
-					self.ptr,
-					pts.as_ptr() as _,
-					pts.len() as _,
-				)
-			},
+			unsafe { gdi32::Polyline(self.0, pts.as_ptr() as _, pts.len() as _) },
 		)
 	}
 
@@ -343,11 +331,7 @@ impl HDC {
 	pub fn PolylineTo(self, pts: &[POINT]) -> WinResult<()> {
 		bool_to_winresult(
 			unsafe {
-				gdi32::PolylineTo(
-					self.ptr,
-					pts.as_ptr() as _,
-					pts.len() as _,
-				)
+				gdi32::PolylineTo(self.0, pts.as_ptr() as _, pts.len() as _)
 			},
 		)
 	}
@@ -355,7 +339,7 @@ impl HDC {
 	/// [`PtVisible`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-ptvisible)
 	/// method.
 	pub fn PtVisible(self, x: i32, y: i32) -> WinResult<bool> {
-		match unsafe { gdi32::PtVisible(self.ptr, x, y) } {
+		match unsafe { gdi32::PtVisible(self.0, x, y) } {
 			-1 => Err(GetLastError()),
 			0 => Ok(false),
 			_ => Ok(true),
@@ -367,7 +351,7 @@ impl HDC {
 	pub fn Rectangle(self, bounds: RECT) -> WinResult<()> {
 		bool_to_winresult(
 			unsafe {
-				gdi32::Rectangle(self.ptr,
+				gdi32::Rectangle(self.0,
 					bounds.left, bounds.top, bounds.right, bounds.bottom)
 			},
 		)
@@ -376,7 +360,7 @@ impl HDC {
 	/// [`RestoreDC`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-restoredc)
 	/// method.
 	pub fn RestoreDC(self, saved_dc: i32) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::RestoreDC(self.ptr, saved_dc) })
+		bool_to_winresult(unsafe { gdi32::RestoreDC(self.0, saved_dc) })
 	}
 
 	/// [`RoundRect`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-roundrect)
@@ -385,7 +369,7 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				gdi32::RoundRect(
-					self.ptr,
+					self.0,
 					bounds.left, bounds.top, bounds.right, bounds.bottom,
 					sz.cx, sz.cy,
 				)
@@ -396,7 +380,7 @@ impl HDC {
 	/// [`SaveDC`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-savedc)
 	/// method.
 	pub fn SaveDC(self) -> WinResult<i32> {
-		match unsafe { gdi32::SaveDC(self.ptr) } {
+		match unsafe { gdi32::SaveDC(self.0) } {
 			0 => Err(GetLastError()),
 			v => Ok(v),
 		}
@@ -405,39 +389,39 @@ impl HDC {
 	/// [`SelectObject`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-selectobject)
 	/// method for [`HBITMAP`](crate::HBITMAP).
 	pub fn SelectObjectBitmap(self, hbmp: HBITMAP) -> WinResult<HBITMAP> {
-		unsafe { gdi32::SelectObject(self.ptr, hbmp.ptr).as_mut() }
-			.map(|ptr| HBITMAP { ptr })
+		unsafe { gdi32::SelectObject(self.0, hbmp.0).as_mut() }
+			.map(|ptr| HBITMAP(ptr))
 			.ok_or_else(|| GetLastError())
 	}
 
 	/// [`SelectObject`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-selectobject)
 	/// method for [`HBRUSH`](crate::HBRUSH).
 	pub fn SelectObjectBrush(self, hbr: HBRUSH) -> WinResult<HBRUSH> {
-		unsafe { gdi32::SelectObject(self.ptr, hbr.ptr).as_mut() }
-			.map(|ptr| HBRUSH { ptr })
+		unsafe { gdi32::SelectObject(self.0, hbr.0).as_mut() }
+			.map(|ptr| HBRUSH(ptr))
 			.ok_or_else(|| GetLastError())
 	}
 
 	/// [`SelectObject`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-selectobject)
 	/// method for [`HFONT`](crate::HFONT).
 	pub fn SelectObjectFont(self, hfont: HFONT) -> WinResult<HFONT> {
-		unsafe { gdi32::SelectObject(self.ptr, hfont.ptr).as_mut() }
-			.map(|ptr| HFONT { ptr })
+		unsafe { gdi32::SelectObject(self.0, hfont.0).as_mut() }
+			.map(|ptr| HFONT(ptr))
 			.ok_or_else(|| GetLastError())
 	}
 
 	/// [`SelectObject`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-selectobject)
 	/// method for [`HPEN`](crate::HPEN).
 	pub fn SelectObjectPen(self, hpen: HPEN) -> WinResult<HPEN> {
-		unsafe { gdi32::SelectObject(self.ptr, hpen.ptr).as_mut() }
-			.map(|ptr| HPEN { ptr })
+		unsafe { gdi32::SelectObject(self.0, hpen.0).as_mut() }
+			.map(|ptr| HPEN(ptr))
 			.ok_or_else(|| GetLastError())
 	}
 
 	/// [`SelectObject`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-selectobject)
 	/// method for [`HRGN`](crate::HRGN).
 	pub fn SelectObjectRgn(self, hrgn: HRGN) -> WinResult<co::REGION> {
-		unsafe { gdi32::SelectObject(self.ptr, hrgn.ptr).as_mut() }
+		unsafe { gdi32::SelectObject(self.0, hrgn.0).as_mut() }
 			.map(|ptr| co::REGION(ptr as *mut _ as _))
 			.ok_or_else(|| GetLastError())
 	}
@@ -445,7 +429,7 @@ impl HDC {
 	/// [`SetArcDirection`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-setarcdirection)
 	/// method.
 	pub fn SetArcDirection(self, dir: co::AD) -> WinResult<co::AD> {
-		match unsafe { gdi32::SetArcDirection(self.ptr, dir.0) } {
+		match unsafe { gdi32::SetArcDirection(self.0, dir.0) } {
 			0 => Err(GetLastError()),
 			v => Ok(co::AD(v)),
 		}
@@ -454,7 +438,7 @@ impl HDC {
 	/// [`SetBkMode`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-setbkmode)
 	/// method.
 	pub fn SetBkMode(self, mode: co::BKMODE) -> WinResult<co::BKMODE> {
-		match unsafe { gdi32::SetBkMode(self.ptr, mode.0) } {
+		match unsafe { gdi32::SetBkMode(self.0, mode.0) } {
 			0 => Err(GetLastError()),
 			v => Ok(co::BKMODE(v)),
 		}
@@ -462,7 +446,7 @@ impl HDC {
 
 	/// [`SetDCBrushColor`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-setdcbrushcolor)
 	pub fn SetDCBrushColor(self, color: COLORREF) -> WinResult<COLORREF> {
-		match unsafe { gdi32::SetDCBrushColor(self.ptr, color.0) } {
+		match unsafe { gdi32::SetDCBrushColor(self.0, color.0) } {
 			CLR_INVALID => Err(GetLastError()),
 			old => Ok(COLORREF(old)),
 		}
@@ -470,7 +454,7 @@ impl HDC {
 
 	/// [`SetDCPenColor`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-setdcpencolor)
 	pub fn SetDCPenColor(self, color: COLORREF) -> WinResult<COLORREF> {
-		match unsafe { gdi32::SetDCPenColor(self.ptr, color.0) } {
+		match unsafe { gdi32::SetDCPenColor(self.0, color.0) } {
 			CLR_INVALID => Err(GetLastError()),
 			old => Ok(COLORREF(old)),
 		}
@@ -479,7 +463,7 @@ impl HDC {
 	/// [`SetGraphicsMode`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-setgraphicsmode)
 	/// method.
 	pub fn SetGraphicsMode(self, mode: co::GM) -> WinResult<co::GM> {
-		match unsafe { gdi32::SetGraphicsMode(self.ptr, mode.0) } {
+		match unsafe { gdi32::SetGraphicsMode(self.0, mode.0) } {
 			0 => Err(GetLastError()),
 			v => Ok(co::GM(v))
 		}
@@ -488,7 +472,7 @@ impl HDC {
 	/// [`SetTextAlign`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-settextalign)
 	/// method.
 	pub fn SetTextAlign(self, align: co::TA) -> WinResult<co::TA> {
-		match unsafe { gdi32::SetTextAlign(self.ptr, align.0) } {
+		match unsafe { gdi32::SetTextAlign(self.0, align.0) } {
 			GDI_ERROR => Err(GetLastError()),
 			ta => Ok(co::TA(ta)),
 		}
@@ -497,7 +481,7 @@ impl HDC {
 	/// [`SetTextColor`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-settextcolor)
 	/// method.
 	pub fn SetTextColor(self, color: COLORREF) -> WinResult<COLORREF> {
-		match unsafe { gdi32::SetTextColor(self.ptr, color.0) } {
+		match unsafe { gdi32::SetTextColor(self.0, color.0) } {
 			CLR_INVALID => Err(GetLastError()),
 			old => Ok(COLORREF(old)),
 		}
@@ -507,7 +491,7 @@ impl HDC {
 	/// method.
 	pub fn SetTextJustification(self, extra: i32, count: i32) -> WinResult<()> {
 		bool_to_winresult(
-			unsafe { gdi32::SetTextJustification(self.ptr, extra, count) },
+			unsafe { gdi32::SetTextJustification(self.0, extra, count) },
 		)
 	}
 
@@ -517,8 +501,8 @@ impl HDC {
 		let mut sz = SIZE::default();
 		bool_to_winresult(
 			unsafe {
-				gdi32::SetViewportExtEx(self.ptr, x, y, &mut sz as *mut _ as _)
-			}
+				gdi32::SetViewportExtEx(self.0, x, y, &mut sz as *mut _ as _)
+			},
 		).map(|_| sz)
 	}
 
@@ -528,8 +512,8 @@ impl HDC {
 		let mut pt = POINT::default();
 		bool_to_winresult(
 			unsafe {
-				gdi32::SetViewportOrgEx(self.ptr, x, y, &mut pt as *mut _ as _)
-			}
+				gdi32::SetViewportOrgEx(self.0, x, y, &mut pt as *mut _ as _)
+			},
 		).map(|_| pt)
 	}
 
@@ -539,8 +523,8 @@ impl HDC {
 		let mut sz = SIZE::default();
 		bool_to_winresult(
 			unsafe {
-				gdi32::SetWindowExtEx(self.ptr, x, y, &mut sz as *mut _ as _)
-			}
+				gdi32::SetWindowExtEx(self.0, x, y, &mut sz as *mut _ as _)
+			},
 		).map(|_| sz)
 	}
 
@@ -550,21 +534,21 @@ impl HDC {
 		let mut pt = POINT::default();
 		bool_to_winresult(
 			unsafe {
-				gdi32::SetWindowOrgEx(self.ptr, x, y, &mut pt as *mut _ as _)
-			}
+				gdi32::SetWindowOrgEx(self.0, x, y, &mut pt as *mut _ as _)
+			},
 		).map(|_| pt)
 	}
 
 	/// [`StrokeAndFillPath`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-strokeandfillpath)
 	/// method.
 	pub fn StrokeAndFillPath(self) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::StrokeAndFillPath(self.ptr) })
+		bool_to_winresult(unsafe { gdi32::StrokeAndFillPath(self.0) })
 	}
 
 	/// [`StrokePath`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-strokepath)
 	/// method.
 	pub fn StrokePath(self) -> WinResult<()> {
-		bool_to_winresult(unsafe { gdi32::StrokePath(self.ptr) })
+		bool_to_winresult(unsafe { gdi32::StrokePath(self.0) })
 	}
 
 	/// [`TextOut`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-textoutw)
@@ -573,7 +557,7 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				gdi32::TextOutW(
-					self.ptr,
+					self.0,
 					x, y,
 					WString::from_str(text).as_ptr(),
 					text.len() as _,
@@ -593,10 +577,10 @@ impl HDC {
 		bool_to_winresult(
 			unsafe {
 				msimg32::TransparentBlt(
-					self.ptr,
+					self.0,
 					dest_top_left.x, dest_top_left.y,
 					dest_sz.cx, dest_sz.cy,
-					hdc_src.ptr,
+					hdc_src.0,
 					src_top_left.x, src_top_left.y,
 					src_sz.cx, src_sz.cy,
 					color_transparent.0,
@@ -608,6 +592,6 @@ impl HDC {
 	/// [`WidenPath`](https://docs.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-widenpath)
 	/// method.
 	pub fn WidenPath(self) -> WinResult<()>  {
-		bool_to_winresult(unsafe { gdi32::WidenPath(self.ptr) })
+		bool_to_winresult(unsafe { gdi32::WidenPath(self.0) })
 	}
 }
