@@ -5,11 +5,13 @@ use crate::ffi::user32;
 use crate::funcs::GetLastError;
 use crate::privs::bool_to_winresult;
 
-pub_struct_handle! {
-	/// Handle to an
-	/// [icon](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#hicon).
-	HICON
-}
+/// Handle to an
+/// [icon](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#hicon).
+#[repr(transparent)]
+#[derive(Copy, Clone, PartialEq, Eq)]
+pub struct HICON(pub(crate) *mut std::ffi::c_void);
+
+impl_handle!(HICON);
 
 impl HICON {
 	/// [`CopyIcon`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-copyicon)
@@ -18,14 +20,14 @@ impl HICON {
 	/// **Note:** Must be paired with an
 	/// [`HICON::DestroyIcon`](crate::HICON::DestroyIcon) call.
 	pub fn CopyIcon(self) -> WinResult<HICON> {
-		unsafe { user32::CopyIcon(self.ptr).as_mut() }
-			.map(|ptr| Self { ptr })
+		unsafe { user32::CopyIcon(self.0).as_mut() }
+			.map(|ptr| Self(ptr))
 			.ok_or_else(|| GetLastError())
 	}
 
 	/// [`DestroyIcon`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-destroyicon)
 	/// method.
 	pub fn DestroyIcon(self) -> WinResult<()> {
-		bool_to_winresult(unsafe { user32::DestroyIcon(self.ptr) })
+		bool_to_winresult(unsafe { user32::DestroyIcon(self.0) })
 	}
 }
