@@ -4,17 +4,19 @@ use crate::aliases::WinResult;
 use crate::ffi::kernel32;
 use crate::funcs::GetLastError;
 
-pub_struct_handle! {
-	/// Handle to a
-	/// [local memory block](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#hlocal).
-	HLOCAL
-}
+/// Handle to a
+/// [local memory block](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#hlocal).
+#[repr(transparent)]
+#[derive(Copy, Clone, PartialEq, Eq)]
+pub struct HLOCAL(pub(crate) *mut std::ffi::c_void);
+
+impl_handle!(HLOCAL);
 
 impl HLOCAL {
 	/// [`LocalFree`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-localfree)
 	/// method.
 	pub fn LocalFree(self) -> WinResult<()> {
-		match unsafe { kernel32::LocalFree(self.ptr).as_mut() } {
+		match unsafe { kernel32::LocalFree(self.0).as_mut() } {
 			None => Ok(()),
 			Some(_) => Err(GetLastError()),
 		}
@@ -23,7 +25,7 @@ impl HLOCAL {
 	/// [`LocalSize`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-localsize)
 	/// method.
 	pub fn LocalSize(self) -> WinResult<u64> {
-		match unsafe { kernel32::LocalSize(self.ptr) } {
+		match unsafe { kernel32::LocalSize(self.0) } {
 			0 => Err(GetLastError()),
 			sz => Ok(sz),
 		}
