@@ -1,7 +1,7 @@
-//! Win32 handles.
+//! Win32
+//! [handles](https://docs.microsoft.com/en-us/windows/win32/sysinfo/handles-and-objects).
 
-#[macro_use]
-mod macros;
+#[macro_use] mod macros;
 
 mod any_handles;
 mod haccel;
@@ -33,6 +33,7 @@ mod htheme;
 mod hthread;
 mod hupdatersrc;
 mod hwnd;
+mod traits;
 
 pub use any_handles::*;
 pub use haccel::HACCEL;
@@ -64,3 +65,7 @@ pub use htheme::HTHEME;
 pub use hthread::HTHREAD;
 pub use hupdatersrc::HUPDATERSRC;
 pub use hwnd::HWND;
+
+pub(crate) mod prelude {
+	pub use super::traits::*;
+}
