@@ -4,7 +4,7 @@
 
 use crate::aliases::WinResult;
 use crate::co;
-use crate::funcs::{HIWORD, LOWORD};
+use crate::funcs::{HIWORD, LOWORD, MAKEDWORD};
 use crate::msg::{MsgSend, WndMsg};
 use crate::msg::macros::zero_as_err;
 use crate::privs::{CB_ERR, CB_ERRSPACE};
@@ -24,12 +24,13 @@ impl MsgSend for AddString {
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
 		match v as i32 {
-			CB_ERR | CB_ERRSPACE => Err(co::ERROR::BAD_ARGUMENTS),
+			CB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			CB_ERRSPACE => Err(co::ERROR::NOT_ENOUGH_MEMORY),
 			idx => Ok(idx as _),
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::ADDSTRING.into(),
 			wparam: 0,
@@ -56,7 +57,7 @@ impl MsgSend for DeleteString {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::DELETESTRING.into(),
 			wparam: self.index as _,
@@ -85,9 +86,9 @@ impl MsgSend for Dir {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
-			msg_id: co::CB::DELETESTRING.into(),
+			msg_id: co::CB::DIR.into(),
 			wparam: self.attributes.0 as _,
 			lparam: unsafe { self.path.as_ptr() } as _,
 		}
@@ -113,10 +114,10 @@ impl MsgSend for FindString {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::FINDSTRING.into(),
-			wparam: self.preceding_index.map(|i| i as _).unwrap_or(-1) as _,
+			wparam: self.preceding_index.map_or(-1, |idx| idx as i32) as _,
 			lparam: unsafe { self.text.as_ptr() } as _,
 		}
 	}
@@ -141,10 +142,10 @@ impl MsgSend for FindStringExact {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::FINDSTRINGEXACT.into(),
-			wparam: self.preceding_index.map(|i| i as _).unwrap_or(-1) as _,
+			wparam: self.preceding_index.map_or(-1, |idx| idx as i32) as _,
 			lparam: unsafe { self.text.as_ptr() } as _,
 		}
 	}
@@ -162,17 +163,14 @@ impl<'a> MsgSend for GetComboBoxInfo<'a> {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETCOMBOBOXINFO.into(),
 			wparam: 0,
-			lparam: self.data as *const _ as _,
+			lparam: self.data as *mut _ as _,
 		}
 	}
 }
@@ -187,13 +185,10 @@ impl MsgSend for GetCount {
 	type RetType = WinResult<u32>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v as i32 {
-			CB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
-			count => Ok(count as _),
-		}
+		zero_as_err(v).map(|count| count as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETCOUNT.into(),
 			wparam: 0,
@@ -220,10 +215,10 @@ impl<'a> MsgSend for GetCueBanner<'a> {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETCUEBANNER.into(),
-			wparam: unsafe { self.buffer.as_ptr() } as _,
+			wparam: unsafe { self.buffer.as_mut_ptr() } as _,
 			lparam: self.buffer.buffer_size() as _,
 		}
 	}
@@ -245,7 +240,7 @@ impl MsgSend for GetCurSel {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETCURSEL.into(),
 			wparam: 0,
@@ -266,17 +261,14 @@ impl<'a> MsgSend for GetDroppedControlRect<'a> {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETDROPPEDCONTROLRECT.into(),
 			wparam: 0,
-			lparam: self.rect as *const _ as _,
+			lparam: self.rect as *mut _ as _,
 		}
 	}
 }
@@ -294,7 +286,7 @@ impl MsgSend for GetDroppedState {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETDROPPEDSTATE.into(),
 			wparam: 0,
@@ -319,7 +311,7 @@ impl MsgSend for GetDroppedWidth {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETDROPPEDWIDTH.into(),
 			wparam: 0,
@@ -341,7 +333,7 @@ impl MsgSend for GetEditSel {
 		(LOWORD(v as _) as _, HIWORD(v as _) as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETEDITSEL.into(),
 			wparam: 0,
@@ -363,7 +355,7 @@ impl MsgSend for GetExtendedUi {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETEXTENDEDUI.into(),
 			wparam: 0,
@@ -385,7 +377,7 @@ impl MsgSend for GetHorizontalExtent {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETHORIZONTALEXTENT.into(),
 			wparam: 0,
@@ -412,7 +404,7 @@ impl MsgSend for GetItemData {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETITEMDATA.into(),
 			wparam: self.index as _,
@@ -430,16 +422,16 @@ pub struct GetItemHeight {
 }
 
 impl MsgSend for GetItemHeight {
-	type RetType = WinResult<i32>;
+	type RetType = WinResult<u32>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
 		match v as i32 {
 			CB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
-			cy => Ok(cy),
+			cy => Ok(cy as _),
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETITEMHEIGHT.into(),
 			wparam: self.component as _,
@@ -467,11 +459,11 @@ impl<'a> MsgSend for GetLbText<'a> {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETLBTEXT.into(),
 			wparam: self.index as _,
-			lparam: unsafe { self.text.as_ptr() } as _,
+			lparam: unsafe { self.text.as_mut_ptr() } as _,
 		}
 	}
 }
@@ -494,7 +486,7 @@ impl MsgSend for GetLbTextLen {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETLBTEXTLEN.into(),
 			wparam: self.index as _,
@@ -516,7 +508,7 @@ impl MsgSend for GetLocale {
 		LANGID(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETLOCALE.into(),
 			wparam: 0,
@@ -538,7 +530,7 @@ impl MsgSend for GetMinVisible {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETMINVISIBLE.into(),
 			wparam: 0,
@@ -563,7 +555,7 @@ impl MsgSend for GetTopIndex {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::GETTOPINDEX.into(),
 			wparam: 0,
@@ -586,12 +578,12 @@ impl MsgSend for InitStorage {
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
 		match v as i32 {
-			CB_ERRSPACE => Err(co::ERROR::BAD_ARGUMENTS),
+			CB_ERRSPACE => Err(co::ERROR::NOT_ENOUGH_MEMORY),
 			n => Ok(n as _),
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::INITSTORAGE.into(),
 			wparam: self.num_items as _,
@@ -600,6 +592,35 @@ impl MsgSend for InitStorage {
 	}
 }
 
+/// [`CB_INSERTSTRING`](https://docs.microsoft.com/en-us/windows/win32/controls/cb-insertstring)
+/// message parameters.
+///
+/// Return type: `WinResult<u32>`.
+pub struct InsertString {
+	pub index: Option<u32>,
+	pub text: WString,
+}
+
+impl MsgSend for InsertString {
+	type RetType = WinResult<u32>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			CB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			CB_ERRSPACE => Err(co::ERROR::NOT_ENOUGH_MEMORY),
+			idx => Ok(idx as _),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::CB::INSERTSTRING.into(),
+			wparam: self.index.map_or(-1, |idx| idx as i32) as _,
+			lparam: unsafe { self.text.as_ptr() } as _,
+		}
+	}
+}
+
 /// [`CB_LIMITTEXT`](https://docs.microsoft.com/en-us/windows/win32/controls/cb-limittext)
 /// message parameters.
 ///
@@ -615,7 +636,7 @@ impl MsgSend for LimitText {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::LIMITTEXT.into(),
 			wparam: self.max_chars.unwrap_or(0) as _,
@@ -647,10 +668,10 @@ impl MsgSend for SelectString {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
-			msg_id: co::CB::SETCURSEL.into(),
-			wparam: self.preceding_index.map(|i| i as i32).unwrap_or(-1) as _,
+			msg_id: co::CB::SELECTSTRING.into(),
+			wparam: self.preceding_index.map_or(-1, |idx| idx as i32) as _,
 			lparam: unsafe { self.search_text.as_ptr() } as _,
 		}
 	}
@@ -674,7 +695,7 @@ impl MsgSend for SetCueBanner {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::SETCUEBANNER.into(),
 			wparam: 0,
@@ -698,7 +719,7 @@ impl MsgSend for SetCurSel {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::SETCURSEL.into(),
 			wparam: match self.index {
@@ -728,7 +749,7 @@ impl MsgSend for SetDroppedWidth {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::SETDROPPEDWIDTH.into(),
 			wparam: self.min_width as _,
@@ -737,6 +758,171 @@ impl MsgSend for SetDroppedWidth {
 	}
 }
 
+/// [`CB_SETEDITSEL`](https://docs.microsoft.com/en-us/windows/win32/controls/cb-seteditsel)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetEditSel {
+	pub start_pos: Option<u32>,
+	pub end_pos: Option<u32>,
+}
+
+impl MsgSend for SetEditSel {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			CB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::CB::SETEDITSEL.into(),
+			wparam: 0,
+			lparam: MAKEDWORD(
+				self.start_pos.map_or(-1, |pos| pos as i16) as _,
+				self.end_pos.map_or(-1, |pos| pos as i16) as _,
+			) as _,
+		}
+	}
+}
+
+/// [`CB_SETEXTENDEDUI`](https://docs.microsoft.com/en-us/windows/win32/controls/cb-setextendedui)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetExtendedUi {
+	pub use_extended_ui: bool,
+}
+
+impl MsgSend for SetExtendedUi {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			CB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::CB::SETEXTENDEDUI.into(),
+			wparam: self.use_extended_ui as _,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`CB_SETHORIZONTALEXTENT`](https://docs.microsoft.com/en-us/windows/win32/controls/cb-sethorizontalextent)
+/// message parameters.
+///
+/// Return type: `()`.
+pub struct SetHorizontalExtent {
+	pub scrollable_width: u32,
+}
+
+impl MsgSend for SetHorizontalExtent {
+	type RetType = ();
+
+	fn convert_ret(&self, _: isize) -> Self::RetType {
+		()
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::CB::SETHORIZONTALEXTENT.into(),
+			wparam: self.scrollable_width as _,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`CB_SETITEMDATA`](https://docs.microsoft.com/en-us/windows/win32/controls/cb-setitemdata)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetItemData {
+	pub index: u32,
+	pub data: isize,
+}
+
+impl MsgSend for SetItemData {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			CB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::CB::SETITEMDATA.into(),
+			wparam: self.index as _,
+			lparam: self.data,
+		}
+	}
+}
+
+/// [`CB_SETITEMHEIGHT`](https://docs.microsoft.com/en-us/windows/win32/controls/cb-setitemheight)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetItemHeight {
+	pub component: i32,
+	pub height: u32,
+}
+
+impl MsgSend for SetItemHeight {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			CB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::CB::SETITEMHEIGHT.into(),
+			wparam: self.component as _,
+			lparam: self.height as _,
+		}
+	}
+}
+
+/// [`CB_SETLOCALE`](https://docs.microsoft.com/en-us/windows/win32/controls/cb-setlocale)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetLocale {
+	pub locale: LANGID,
+}
+
+impl MsgSend for SetLocale {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			CB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::CB::SETLOCALE.into(),
+			wparam: self.locale.0 as _,
+			lparam: 0,
+		}
+	}
+}
+
 /// [`CB_SETMINVISIBLE`](https://docs.microsoft.com/en-us/windows/win32/controls/cb-setminvisible)
 /// message parameters.
 ///
@@ -752,7 +938,7 @@ impl MsgSend for SetMinVisible {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::SETMINVISIBLE.into(),
 			wparam: self.num_items as _,
@@ -776,7 +962,7 @@ impl MsgSend for SetTopIndex {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::SETTOPINDEX.into(),
 			wparam: self.index as _,
@@ -800,7 +986,7 @@ impl MsgSend for ShowDropDown {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::CB::SHOWDROPDOWN.into(),
 			wparam: self.show as _,
