@@ -8,7 +8,7 @@ use crate::funcs::{HIWORD, LOWORD, MAKEDWORD};
 use crate::msg::{MsgSend, WndMsg};
 use crate::msg::macros::{point_to_lp, zero_as_err};
 use crate::privs::{LB_ERR, LB_ERRSPACE};
-use crate::structs::{POINT, RECT};
+use crate::structs::{LCID, POINT, RECT};
 use crate::various::WString;
 
 /// [`LB_ADDFILE`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-addfile)
@@ -24,14 +24,15 @@ impl MsgSend for AddFile {
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
 		match v as i32 {
-			LB_ERR | LB_ERRSPACE => Err(co::ERROR::BAD_ARGUMENTS),
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			LB_ERRSPACE => Err(co::ERROR::NOT_ENOUGH_MEMORY),
 			idx => Ok(idx as _),
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
-			msg_id: co::LB::ADDSTRING.into(),
+			msg_id: co::LB::ADDFILE.into(),
 			wparam: 0,
 			lparam: unsafe { self.text.as_ptr() } as _,
 		}
@@ -51,12 +52,13 @@ impl MsgSend for AddString {
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
 		match v as i32 {
-			LB_ERR | LB_ERRSPACE => Err(co::ERROR::BAD_ARGUMENTS),
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			LB_ERRSPACE => Err(co::ERROR::NOT_ENOUGH_MEMORY),
 			idx => Ok(idx as _),
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::ADDSTRING.into(),
 			wparam: 0,
@@ -83,7 +85,7 @@ impl MsgSend for DeleteString {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::DELETESTRING.into(),
 			wparam: self.index as _,
@@ -112,9 +114,9 @@ impl MsgSend for Dir {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
-			msg_id: co::LB::DELETESTRING.into(),
+			msg_id: co::LB::DIR.into(),
 			wparam: self.attributes.0 as _,
 			lparam: unsafe { self.path.as_ptr() } as _,
 		}
@@ -140,13 +142,10 @@ impl MsgSend for FindString {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::FINDSTRING.into(),
-			wparam: match self.preceding_index {
-				None => -1,
-				Some(idx) => idx as i32,
-			} as _,
+			wparam: self.preceding_index.map_or(-1, |idx| idx as i32) as _,
 			lparam: unsafe { self.text.as_ptr() } as _,
 		}
 	}
@@ -171,13 +170,10 @@ impl MsgSend for FindStringExact {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::FINDSTRINGEXACT.into(),
-			wparam: match self.preceding_index {
-				None => -1,
-				Some(idx) => idx as i32,
-			} as _,
+			wparam: self.preceding_index.map_or(-1, |idx| idx as i32) as _,
 			lparam: unsafe { self.text.as_ptr() } as _,
 		}
 	}
@@ -196,7 +192,7 @@ impl MsgSend for GetAnchorIndex {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETANCHORINDEX.into(),
 			wparam: 0,
@@ -218,7 +214,7 @@ impl MsgSend for GetCaretIndex {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETCARETINDEX.into(),
 			wparam: 0,
@@ -243,7 +239,7 @@ impl MsgSend for GetCount {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETCOUNT.into(),
 			wparam: 0,
@@ -268,7 +264,7 @@ impl MsgSend for GetCurSel {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETCURSEL.into(),
 			wparam: 0,
@@ -290,7 +286,7 @@ impl MsgSend for GetHorizontalExtent {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETHORIZONTALEXTENT.into(),
 			wparam: 0,
@@ -318,10 +314,10 @@ impl MsgSend for GetItemData {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETITEMDATA.into(),
-			wparam: 0,
+			wparam: self.index as _,
 			lparam: 0,
 		}
 	}
@@ -330,13 +326,13 @@ impl MsgSend for GetItemData {
 /// [`LB_GETITEMHEIGHT`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-getitemheight)
 /// message parameters.
 ///
-/// Return type: `WinResult<u32>`.
+/// Return type: `WinResult<u8>`.
 pub struct GetItemHeight {
 	pub index: Option<u32>,
 }
 
 impl MsgSend for GetItemHeight {
-	type RetType = WinResult<u32>;
+	type RetType = WinResult<u8>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
 		match v as i32 {
@@ -345,10 +341,10 @@ impl MsgSend for GetItemHeight {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETITEMHEIGHT.into(),
-			wparam: self.index.unwrap_or_default() as _,
+			wparam: self.index.unwrap_or(0) as _,
 			lparam: 0,
 		}
 	}
@@ -373,11 +369,11 @@ impl<'a> MsgSend for GetItemRect<'a> {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETITEMRECT.into(),
 			wparam: self.index as _,
-			lparam: self.rect as *const _ as _,
+			lparam: self.rect as *mut _ as _,
 		}
 	}
 }
@@ -395,7 +391,7 @@ impl MsgSend for GetListBoxInfo {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETLISTBOXINFO.into(),
 			wparam: 0,
@@ -404,6 +400,28 @@ impl MsgSend for GetListBoxInfo {
 	}
 }
 
+/// [`LB_GETLOCALE`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-getlocale)
+/// message, which has no parameters.
+///
+/// Return type: `LCID`.
+pub struct GetLocale {}
+
+impl MsgSend for GetLocale {
+	type RetType = LCID;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		LCID(v as _)
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::GETLOCALE.into(),
+			wparam: 0,
+			lparam: 0,
+		}
+	}
+}
+
 /// [`LB_GETSEL`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-getsel)
 /// message parameters.
 ///
@@ -422,7 +440,7 @@ impl MsgSend for GetSel {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETSEL.into(),
 			wparam: self.index as _,
@@ -447,7 +465,7 @@ impl MsgSend for GetSelCount {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETSELCOUNT.into(),
 			wparam: 0,
@@ -474,11 +492,11 @@ impl<'a> MsgSend for GetSelItems<'a> {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETSELITEMS.into(),
 			wparam: self.buffer.len(),
-			lparam: self.buffer.as_ptr() as _,
+			lparam: self.buffer.as_mut_ptr() as _,
 		}
 	}
 }
@@ -502,11 +520,11 @@ impl<'a> MsgSend for GetText<'a> {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETTEXT.into(),
 			wparam: self.index as _,
-			lparam: unsafe { self.text.as_ptr() } as _,
+			lparam: unsafe { self.text.as_mut_ptr() } as _,
 		}
 	}
 }
@@ -529,7 +547,7 @@ impl MsgSend for GetTextLen {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETTEXTLEN.into(),
 			wparam: self.index as _,
@@ -554,7 +572,7 @@ impl MsgSend for GetTopIndex {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::GETTOPINDEX.into(),
 			wparam: 0,
@@ -582,7 +600,7 @@ impl MsgSend for InitStorage {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::INITSTORAGE.into(),
 			wparam: self.num_items as _,
@@ -605,15 +623,16 @@ impl MsgSend for InsertString {
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
 		match v as i32 {
-			LB_ERR | LB_ERRSPACE => Err(co::ERROR::BAD_ARGUMENTS),
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			LB_ERRSPACE => Err(co::ERROR::NOT_ENOUGH_MEMORY),
 			idx => Ok(idx as _),
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::INSERTSTRING.into(),
-			wparam: self.insertion_index.map(|i| i as i32).unwrap_or(-1) as _,
+			wparam: self.insertion_index.map_or(-1, |idx| idx as i32) as _,
 			lparam: unsafe { self.text.as_ptr() } as _,
 		}
 	}
@@ -634,7 +653,7 @@ impl MsgSend for ItemFromPoint {
 		(LOWORD(v as _) as _, HIWORD(v as _) == 1)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::ITEMFROMPOINT.into(),
 			wparam: 0,
@@ -661,18 +680,16 @@ impl MsgSend for SelectString {
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
 		match v as i32 {
-			LB_ERR | LB_ERRSPACE => Err(co::ERROR::BAD_ARGUMENTS),
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			LB_ERRSPACE => Err(co::ERROR::NOT_ENOUGH_MEMORY),
 			idx => Ok(idx as _),
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::SELECTSTRING.into(),
-			wparam: match self.index {
-				None => -1,
-				Some(idx) => idx as i32,
-			} as _,
+			wparam: self.index.map_or(-1, |idx| idx as i32) as _,
 			lparam: unsafe { self.prefix.as_ptr() } as _,
 		}
 	}
@@ -684,8 +701,8 @@ impl MsgSend for SelectString {
 /// Return type: `WinResult<()>`.
 pub struct SelItemRange {
 	pub select: bool,
-	pub first_item: u32,
-	pub last_item: u32,
+	pub first_item: u16,
+	pub last_item: u16,
 }
 
 impl MsgSend for SelItemRange {
@@ -698,11 +715,39 @@ impl MsgSend for SelItemRange {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::SELITEMRANGE.into(),
-			wparam: self.select as usize,
-			lparam: MAKEDWORD(self.first_item as _, self.last_item as _) as _,
+			wparam: self.select as _,
+			lparam: MAKEDWORD(self.first_item, self.last_item) as _,
+		}
+	}
+}
+
+/// [`LB_SELITEMRANGEEX`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-selitemrangeex)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SelItemRangeEx {
+	pub first_index: u32,
+	pub last_index: u32,
+}
+
+impl MsgSend for SelItemRangeEx {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::SELITEMRANGEEX.into(),
+			wparam: self.first_index as _,
+			lparam: self.last_index as _,
 		}
 	}
 }
@@ -725,7 +770,7 @@ impl MsgSend for SetAnchorIndex {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::SETANCHORINDEX.into(),
 			wparam: self.index as _,
@@ -734,6 +779,224 @@ impl MsgSend for SetAnchorIndex {
 	}
 }
 
+/// [`LB_SETCARETINDEX`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-setcaretindex)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetCaretIndex {
+	pub index: u32,
+	pub at_least_partially_visible: bool,
+}
+
+impl MsgSend for SetCaretIndex {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::SETCARETINDEX.into(),
+			wparam: self.index as _,
+			lparam: self.at_least_partially_visible as _,
+		}
+	}
+}
+
+/// [`LB_SETCOLUMNWIDTH`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-setcolumnwidth)
+/// message parameters.
+///
+/// Return type: `()`.
+pub struct SetColumnWidth {
+	pub width: u32,
+}
+
+impl MsgSend for SetColumnWidth {
+	type RetType = ();
+
+	fn convert_ret(&self, _: isize) -> Self::RetType {
+		()
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::SETCOLUMNWIDTH.into(),
+			wparam: self.width as _,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`LB_SETCOUNT`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-setcount)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetCount {
+	pub new_count: u32,
+}
+
+impl MsgSend for SetCount {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			LB_ERRSPACE => Err(co::ERROR::NOT_ENOUGH_MEMORY),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::SETCOUNT.into(),
+			wparam: self.new_count as _,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`LB_SETCURSEL`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-setcursel)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetCurSel {
+	pub index: Option<u32>,
+}
+
+impl MsgSend for SetCurSel {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		if let None = self.index {
+			Ok(())
+		} else {
+			match v as i32 {
+				LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+				_ => Ok(()),
+			}
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::SETCURSEL.into(),
+			wparam: self.index.map_or(-1, |idx| idx as i32) as _,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`LB_SETHORIZONTALEXTENT`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-sethorizontalextent)
+/// message parameters.
+///
+/// Return type: `()`.
+pub struct SetHorizontalExtent {
+	pub width: u32,
+}
+
+impl MsgSend for SetHorizontalExtent {
+	type RetType = ();
+
+	fn convert_ret(&self, _: isize) -> Self::RetType {
+		()
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::SETHORIZONTALEXTENT.into(),
+			wparam: self.width as _,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`LB_SETITEMDATA`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-setitemdata)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetItemData {
+	pub index: u32,
+	pub data: isize,
+}
+
+impl MsgSend for SetItemData {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::SETITEMDATA.into(),
+			wparam: self.index as _,
+			lparam: self.data,
+		}
+	}
+}
+
+/// [`LB_SETITEMHEIGHT`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-setitemheight)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct SetItemHeight {
+	pub index: Option<u32>,
+	pub height: u8,
+}
+
+impl MsgSend for SetItemHeight {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			_ => Ok(()),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::SETITEMHEIGHT.into(),
+			wparam: self.index.unwrap_or(0) as _,
+			lparam: self.height as _,
+		}
+	}
+}
+
+/// [`LB_SETLOCALE`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-setlocale)
+/// message parameters.
+///
+/// Return type: `WinResult<LCID>`.
+pub struct SetLocale {
+	pub locale: LCID,
+}
+
+impl MsgSend for SetLocale {
+	type RetType = WinResult<LCID>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			LB_ERR => Err(co::ERROR::BAD_ARGUMENTS),
+			lcid => Ok(LCID(lcid as _)),
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LB::SETLOCALE.into(),
+			wparam: self.locale.0 as _,
+			lparam: 0,
+		}
+	}
+}
+
 /// [`LB_SETSEL`](https://docs.microsoft.com/en-us/windows/win32/controls/lb-setsel)
 /// message parameters.
 ///
@@ -753,11 +1016,11 @@ impl MsgSend for SetSel {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::SETSEL.into(),
 			wparam: self.select as _,
-			lparam: self.index.map(|i| i as i32).unwrap_or(-1) as _,
+			lparam: self.index.map_or(-1, |idx| idx as i32) as _,
 		}
 	}
 }
@@ -777,7 +1040,7 @@ impl<'a> MsgSend for SetTabStops<'a> {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::SETTABSTOPS.into(),
 			wparam: self.tab_stops.len(),
@@ -804,7 +1067,7 @@ impl MsgSend for SetTopIndex {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LB::SETTOPINDEX.into(),
 			wparam: self.index as _,
