@@ -38,22 +38,13 @@ impl MsgSend for ApproximateViewRect {
 		SIZE::new(LOWORD(v as _) as _, HIWORD(v as _) as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::APPROXIMATEVIEWRECT.into(),
-			wparam: match self.num_items {
-				None => -1,
-				Some(num) => num as isize,
-			} as _,
+			wparam: self.num_items.map_or(-1, |n| n as i32) as _,
 			lparam: MAKEDWORD(
-				match self.proposed_x {
-					None => -1,
-					Some(x) => x as i32,
-				} as _,
-				match self.proposed_y {
-					None => -1,
-					Some(y) => y as i32,
-				} as _,
+				self.proposed_x.map_or(-1, |x| x as i32) as _,
+				self.proposed_y.map_or(-1, |y| y as i32) as _,
 			) as _,
 		}
 	}
@@ -74,7 +65,7 @@ impl MsgSend for Arrange {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::ARRANGE.into(),
 			wparam: self.arrangement.0 as _,
@@ -100,7 +91,7 @@ impl MsgSend for DeleteAllItems {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::DELETEALLITEMS.into(),
 			wparam: 0,
@@ -124,7 +115,7 @@ impl MsgSend for DeleteItem {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::DELETEITEM.into(),
 			wparam: self.index as _,
@@ -149,7 +140,7 @@ impl MsgSend for EnsureVisible {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::ENSUREVISIBLE.into(),
 			wparam: self.index as _,
@@ -177,10 +168,10 @@ impl<'a, 'b> MsgSend for FindItem<'a, 'b> {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::FINDITEM.into(),
-			wparam: self.start_index.map(|i| i as i32).unwrap_or(-1) as _,
+			wparam: self.start_index.map_or(-1, |idx| idx as i32) as _,
 			lparam: self.lvfindinfo as *const _ as _,
 		}
 	}
@@ -199,7 +190,7 @@ impl MsgSend for GetBkColor {
 		COLORREF(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETBKCOLOR.into(),
 			wparam: 0,
@@ -224,11 +215,11 @@ impl<'a, 'b> MsgSend for GetColumn<'a, 'b> {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETCOLUMN.into(),
 			wparam: self.index as _,
-			lparam: self.lvcolumn as *const _ as _,
+			lparam: self.lvcolumn as *mut _ as _,
 		}
 	}
 }
@@ -248,11 +239,11 @@ impl<'a> MsgSend for GetColumnOrderArray<'a> {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETCOLUMNORDERARRAY.into(),
 			wparam: self.indexes.len() as _,
-			lparam: self.indexes.as_ptr() as _,
+			lparam: self.indexes.as_mut_ptr() as _,
 		}
 	}
 }
@@ -275,7 +266,7 @@ impl MsgSend for GetColumnWidth {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETCOLUMNWIDTH.into(),
 			wparam: self.index as _,
@@ -297,7 +288,7 @@ impl MsgSend for GetCountPerPage {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETCOUNTPERPAGE.into(),
 			wparam: 0,
@@ -319,7 +310,7 @@ impl MsgSend for GetExtendedListViewStyle {
 		co::LVS_EX(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETEXTENDEDLISTVIEWSTYLE.into(),
 			wparam: 0,
@@ -338,10 +329,10 @@ impl MsgSend for GetHeader {
 	type RetType = WinResult<HWND>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		zero_as_err(v).map(|p| HWND { ptr: p as _ })
+		zero_as_err(v).map(|p| HWND(p as _))
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETHEADER.into(),
 			wparam: 0,
@@ -362,10 +353,10 @@ impl MsgSend for GetImageList {
 	type RetType = Option<HIMAGELIST>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		zero_as_none(v).map(|p| HIMAGELIST { ptr: p as _ })
+		zero_as_none(v).map(|p| HIMAGELIST(p as _))
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETIMAGELIST.into(),
 			wparam: self.kind.0 as _,
@@ -374,6 +365,30 @@ impl MsgSend for GetImageList {
 	}
 }
 
+/// [`LVM_GETITEM`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getitem)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct GetItem<'a, 'b> {
+	pub lvitem: &'b mut LVITEM<'a>,
+}
+
+impl<'a, 'b> MsgSend for GetItem<'a, 'b> {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		zero_as_err(v).map(|_| ())
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETITEM.into(),
+			wparam: 0,
+			lparam: self.lvitem as *mut _ as _,
+		}
+	}
+}
+
 /// [`LVM_GETITEMCOUNT`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getitemcount)
 /// message, which has no parameters.
 ///
@@ -387,7 +402,7 @@ impl MsgSend for GetItemCount {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETITEMCOUNT.into(),
 			wparam: 0,
@@ -412,7 +427,7 @@ impl MsgSend for GetItemState {
 		co::LVIS(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETITEMSTATE.into(),
 			wparam: self.index as _,
@@ -437,11 +452,11 @@ impl<'a, 'b> MsgSend for GetItemText<'a, 'b> {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETITEMTEXT.into(),
 			wparam: self.index as _,
-			lparam: self.lvitem as *const _ as _,
+			lparam: self.lvitem as *mut _ as _,
 		}
 	}
 }
@@ -463,14 +478,13 @@ impl<'a> MsgSend for GetItemRect<'a> {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
-		let ptr_rect = self.rect as *const _ as *mut RECT;
-		unsafe { &mut *ptr_rect }.left = self.portion.0 as _;
+	fn as_generic_wm(&mut self) -> WndMsg {
+		self.rect.left = self.portion.0 as _;
 
 		WndMsg {
 			msg_id: co::LVM::GETITEMRECT.into(),
 			wparam: self.index as _,
-			lparam: self.rect as *const _ as _,
+			lparam: self.rect as *mut _ as _,
 		}
 	}
 }
@@ -494,10 +508,10 @@ impl MsgSend for GetNextItem {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETNEXTITEM.into(),
-			wparam: self.initial_index.map(|i| i as i32).unwrap_or(-1) as _,
+			wparam: self.initial_index.map_or(-1, |idx| idx as i32) as _,
 			lparam: self.relationship.0 as _,
 		}
 	}
@@ -519,10 +533,10 @@ impl<'a> MsgSend for GetNextItemIndex<'a> {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETNEXTITEMINDEX.into(),
-			wparam: self.initial_item as *const _ as _,
+			wparam: self.initial_item as *mut _ as _,
 			lparam: self.relationship.0 as _,
 		}
 	}
@@ -543,11 +557,11 @@ impl<'a> MsgSend for GetNumberOfWorkAreas<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETNUMBEROFWORKAREAS.into(),
 			wparam: 0,
-			lparam: self.num as *const _ as _,
+			lparam: self.num as *mut _ as _,
 		}
 	}
 }
@@ -567,11 +581,11 @@ impl<'a> MsgSend for GetOrigin<'a> {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETORIGIN.into(),
 			wparam: 0,
-			lparam: self.origin as *const _ as _,
+			lparam: self.origin as *mut _ as _,
 		}
 	}
 }
@@ -589,7 +603,7 @@ impl MsgSend for GetOutlineColor {
 		COLORREF(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETOUTLINECOLOR.into(),
 			wparam: 0,
@@ -614,7 +628,7 @@ impl MsgSend for GetSelectedColumn {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETSELECTEDCOLUMN.into(),
 			wparam: 0,
@@ -636,7 +650,7 @@ impl MsgSend for GetSelectedCount {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETSELECTEDCOUNT.into(),
 			wparam: 0,
@@ -661,7 +675,7 @@ impl MsgSend for GetSelectionMark {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETSELECTIONMARK.into(),
 			wparam: 0,
@@ -682,13 +696,10 @@ impl MsgSend for GetStringWidth {
 	type RetType = WinResult<u32>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			len => Ok(len as _),
-		}
+		zero_as_err(v).map(|len| len as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETSTRINGWIDTH.into(),
 			wparam: 0,
@@ -710,7 +721,7 @@ impl MsgSend for GetTextBkColor {
 		COLORREF(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETTEXTBKCOLOR.into(),
 			wparam: 0,
@@ -732,7 +743,7 @@ impl MsgSend for GetTextColor {
 		COLORREF(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETTEXTCOLOR.into(),
 			wparam: 0,
@@ -757,7 +768,7 @@ impl MsgSend for GetTopIndex {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETTOPINDEX.into(),
 			wparam: 0,
@@ -779,7 +790,7 @@ impl MsgSend for GetView {
 		co::LV_VIEW(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETVIEW.into(),
 			wparam: 0,
@@ -803,11 +814,11 @@ impl<'a> MsgSend for GetViewRect<'a> {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::GETVIEWRECT.into(),
 			wparam: 0,
-			lparam: self.rect as *const _ as _,
+			lparam: self.rect as *mut _ as _,
 		}
 	}
 }
@@ -830,11 +841,11 @@ impl<'a> MsgSend for HitTest<'a> {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::HITTEST.into(),
 			wparam: -1 as _,
-			lparam: self.info as *const _ as _,
+			lparam: self.info as *mut _ as _,
 		}
 	}
 }
@@ -858,7 +869,7 @@ impl<'a, 'b> MsgSend for InsertColumn<'a, 'b> {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::INSERTCOLUMN.into(),
 			wparam: self.index as _,
@@ -885,7 +896,7 @@ impl<'a, 'b> MsgSend for InsertItem<'a, 'b> {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::INSERTITEM.into(),
 			wparam: 0,
@@ -907,7 +918,7 @@ impl MsgSend for IsGroupViewEnabled {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::ISGROUPVIEWENABLED.into(),
 			wparam: 0,
@@ -931,7 +942,7 @@ impl MsgSend for IsItemVisible {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::ISITEMVISIBLE.into(),
 			wparam: self.index as _,
@@ -958,7 +969,7 @@ impl MsgSend for MapIdToIndex {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::MAPIDTOINDEX.into(),
 			wparam: self.id as _,
@@ -985,7 +996,7 @@ impl MsgSend for MapIndexToId {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::MAPINDEXTOID.into(),
 			wparam: self.index as _,
@@ -1010,7 +1021,7 @@ impl MsgSend for RedrawItems {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::REDRAWITEMS.into(),
 			wparam: self.first_index as _,
@@ -1035,7 +1046,7 @@ impl MsgSend for Scroll {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SCROLL.into(),
 			wparam: self.horizontal as _,
@@ -1060,7 +1071,7 @@ impl<'a, 'b> MsgSend for SetColumn<'a, 'b> {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SETCOLUMN.into(),
 			wparam: self.index as _,
@@ -1085,7 +1096,7 @@ impl MsgSend for SetColumnWidth {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SETCOLUMNWIDTH.into(),
 			wparam: self.index as _,
@@ -1110,7 +1121,7 @@ impl MsgSend for SetExtendedListViewStyle {
 		co::LVS_EX(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SETEXTENDEDLISTVIEWSTYLE.into(),
 			wparam: self.style.0 as _,
@@ -1132,14 +1143,14 @@ impl MsgSend for SetImageList {
 	type RetType = Option<HIMAGELIST>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		zero_as_none(v).map(|p| HIMAGELIST { ptr: p as _ })
+		zero_as_none(v).map(|p| HIMAGELIST(p as _))
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SETIMAGELIST.into(),
 			wparam: self.kind.0 as _,
-			lparam: self.himagelist.ptr as _,
+			lparam: self.himagelist.0 as _,
 		}
 	}
 }
@@ -1159,7 +1170,7 @@ impl<'a, 'b> MsgSend for SetItem<'a, 'b> {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SETITEM.into(),
 			wparam: 0,
@@ -1184,10 +1195,10 @@ impl<'a, 'b> MsgSend for SetItemState<'a, 'b> {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SETITEMSTATE.into(),
-			wparam: self.index.map(|i| i as i32).unwrap_or(-1) as _,
+			wparam: self.index.map_or(-1, |idx| idx as i32) as _,
 			lparam: self.lvitem as *const _ as _,
 		}
 	}
@@ -1209,7 +1220,7 @@ impl<'a, 'b> MsgSend for SetItemText<'a, 'b> {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SETITEMTEXT.into(),
 			wparam: self.index as _,
@@ -1233,7 +1244,7 @@ impl MsgSend for SetSelectedColumn {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SETSELECTEDCOLUMN.into(),
 			wparam: self.index as _,
@@ -1260,7 +1271,7 @@ impl MsgSend for SetView {
 		}
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::SETVIEW.into(),
 			wparam: self.view.0 as _,
@@ -1284,7 +1295,7 @@ impl MsgSend for Update {
 		zero_as_err(v).map(|_| ())
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::LVM::UPDATE.into(),
 			wparam: self.index as _,
