@@ -33,8 +33,7 @@
 //! [`wm`](crate::msg::wm) (window messages), [`lvm`](crate::msg::lvm) (list
 //! view messages), and so on.
 
-#[macro_use]
-mod macros;
+#[macro_use] mod macros;
 
 mod message;
 pub use message::{MsgSend, MsgSendRecv, WndMsg};
@@ -54,3 +53,7 @@ pub mod tbm;
 pub mod trbm;
 pub mod tvm;
 pub mod wm;
+
+pub(crate) mod prelude {
+	pub use super::message::{MsgSend, MsgSendRecv};
+}
