@@ -16,7 +16,7 @@ use crate::funcs::{HIBYTE, HIWORD, LOBYTE, LOWORD, MAKEDWORD, MAKEWORD};
 use crate::handles::{HBRUSH, HDC, HDROP, HFONT, HICON, HMENU, HRGN, HWND};
 use crate::msg::{MsgSend, MsgSendRecv, WndMsg};
 use crate::msg::macros::{lp_to_point, point_to_lp, zero_as_none};
-use crate::privs::FAPPCOMMAND_MASK;
+use crate::privs::{CB_ERR, FAPPCOMMAND_MASK, LB_ERRSPACE};
 use crate::structs::{
 	CREATESTRUCT,
 	DELETEITEMSTRUCT,
@@ -49,11 +49,11 @@ impl MsgSend for Activate {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::ACTIVATE,
 			wparam: MAKEDWORD(self.event.0, self.is_minimized as _) as _,
-			lparam: self.hwnd.ptr as _,
+			lparam: self.hwnd.0 as _,
 		}
 	}
 }
@@ -63,7 +63,7 @@ impl MsgSendRecv for Activate {
 		Self {
 			event: co::WA(LOWORD(p.wparam as _)),
 			is_minimized: HIWORD(p.wparam as _) != 0,
-			hwnd: HWND { ptr: p.lparam as _ },
+			hwnd: HWND(p.lparam as _),
 		}
 	}
 }
@@ -84,7 +84,7 @@ impl MsgSend for ActivateApp {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::ACTIVATEAPP,
 			wparam: self.is_being_activated as _,
@@ -120,10 +120,10 @@ impl MsgSend for AppCommand {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::APPCOMMAND,
-			wparam: self.hwnd_owner.ptr as _,
+			wparam: self.hwnd_owner.0 as _,
 			lparam: MAKEDWORD(self.keys.into(), self.app_command.0 | self.u_device.0) as _,
 		}
 	}
@@ -132,7 +132,7 @@ impl MsgSend for AppCommand {
 impl MsgSendRecv for AppCommand {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hwnd_owner: HWND { ptr: p.wparam as _ },
+			hwnd_owner: HWND(p.wparam as _),
 			app_command: co::APPCOMMAND(HIWORD(p.lparam as _) & !FAPPCOMMAND_MASK),
 			u_device: co::FAPPCOMMAND(HIWORD(p.lparam as _) & FAPPCOMMAND_MASK),
 			keys: co::MK(LOWORD(p.lparam as _)),
@@ -159,10 +159,10 @@ impl MsgSend for CaptureChanged {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::CAPTURECHANGED,
-			wparam: self.hwnd_gaining_mouse.ptr as _,
+			wparam: self.hwnd_gaining_mouse.0 as _,
 			lparam: 0,
 		}
 	}
@@ -171,7 +171,7 @@ impl MsgSend for CaptureChanged {
 impl MsgSendRecv for CaptureChanged {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hwnd_gaining_mouse: HWND { ptr: p.wparam as _ },
+			hwnd_gaining_mouse: HWND(p.wparam as _),
 		}
 	}
 }
@@ -203,7 +203,7 @@ impl MsgSend for Command {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::COMMAND,
 			wparam: match self.event {
@@ -214,7 +214,7 @@ impl MsgSend for Command {
 			lparam: match self.event {
 				AccelMenuCtrl::Accel(_) => co::CMD::Accelerator.0 as _,
 				AccelMenuCtrl::Menu(_) => co::CMD::Menu.0 as _,
-				AccelMenuCtrl::Ctrl(data) => data.ctrl_hwnd.ptr as _,
+				AccelMenuCtrl::Ctrl(data) => data.ctrl_hwnd.0 as _,
 			},
 		}
 	}
@@ -230,7 +230,7 @@ impl MsgSendRecv for Command {
 					AccelMenuCtrlData {
 						notif_code: co::CMD(code),
 						ctrl_id: LOWORD(p.wparam as _),
-						ctrl_hwnd: HWND { ptr: p.lparam as _ },
+						ctrl_hwnd: HWND(p.lparam as _),
 					},
 				),
 			},
@@ -254,10 +254,10 @@ impl MsgSend for ContextMenu {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::CONTEXTMENU,
-			wparam: self.hwnd.ptr as _,
+			wparam: self.hwnd.0 as _,
 			lparam: point_to_lp(self.cursor_pos),
 		}
 	}
@@ -266,7 +266,7 @@ impl MsgSend for ContextMenu {
 impl MsgSendRecv for ContextMenu {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hwnd: HWND { ptr: p.wparam as _ },
+			hwnd: HWND(p.wparam as _),
 			cursor_pos: lp_to_point(p),
 		}
 	}
@@ -287,7 +287,7 @@ impl<'a, 'b, 'c> MsgSend for Create<'a, 'b, 'c> {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::CREATE,
 			wparam: 0,
@@ -348,7 +348,7 @@ impl<'a> MsgSend for DeleteItem<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::DELETEITEM,
 			wparam: self.control_id as _,
@@ -387,7 +387,7 @@ impl MsgSend for DisplayChange {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::DISPLAYCHANGE,
 			wparam: self.depth_bpp as _,
@@ -421,10 +421,10 @@ impl MsgSend for DropFiles {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::DROPFILES,
-			wparam: self.hdrop.ptr as _,
+			wparam: self.hdrop.0 as _,
 			lparam: 0,
 		}
 	}
@@ -433,7 +433,7 @@ impl MsgSend for DropFiles {
 impl MsgSendRecv for DropFiles {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hdrop: HDROP { ptr: p.wparam as _ },
+			hdrop: HDROP(p.wparam as _),
 		}
 	}
 }
@@ -453,7 +453,7 @@ impl MsgSend for Enable {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::ENABLE,
 			wparam: self.has_been_enabled as _,
@@ -486,7 +486,7 @@ impl MsgSend for EndSession {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::ENDSESSION,
 			wparam: self.is_session_being_ended as _,
@@ -520,7 +520,7 @@ impl MsgSend for EnterIdle {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::ENTERIDLE,
 			wparam: self.reason.0 as _,
@@ -535,8 +535,8 @@ impl MsgSendRecv for EnterIdle {
 		Self {
 			reason,
 			handle: match reason {
-				co::MSGF::DIALOGBOX => HwndHmenu::Hwnd(HWND { ptr: p.lparam as _ }),
-				_ => HwndHmenu::Hmenu(HMENU { ptr: p.lparam as _ }),
+				co::MSGF::DIALOGBOX => HwndHmenu::Hwnd(HWND(p.lparam as _)),
+				_ => HwndHmenu::Hmenu(HMENU(p.lparam as _)),
 			},
 		}
 	}
@@ -561,7 +561,7 @@ impl MsgSend for EnterMenuLoop {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::ENTERMENULOOP,
 			wparam: self.with_trackpopupmenu as _,
@@ -593,10 +593,10 @@ impl MsgSend for EraseBkgnd {
 		v as _
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::ERASEBKGND,
-			wparam: self.hdc.ptr as _,
+			wparam: self.hdc.0 as _,
 			lparam: 0,
 		}
 	}
@@ -605,7 +605,7 @@ impl MsgSend for EraseBkgnd {
 impl MsgSendRecv for EraseBkgnd {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hdc: HDC { ptr: p.wparam as _ },
+			hdc: HDC(p.wparam as _),
 		}
 	}
 }
@@ -625,7 +625,7 @@ impl MsgSend for ExitMenuLoop {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::EXITMENULOOP,
 			wparam: self.is_shortcut as _,
@@ -662,11 +662,11 @@ impl<'a> MsgSend for GetDlgCode<'a> {
 		co::DLGC(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::GETDLGCODE,
 			wparam: self.vkey_code.0 as _,
-			lparam: self.msg.as_ref().map_or(0, |m| m as *const _ as _),
+			lparam: self.msg.as_mut().map_or(0, |m| m as *mut _ as _),
 		}
 	}
 }
@@ -693,10 +693,10 @@ impl MsgSend for GetFont {
 	type RetType = Option<HFONT>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		zero_as_none(v).map(|p| HFONT { ptr: p as _ })
+		zero_as_none(v).map(|p| HFONT(p as _))
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::GETFONT,
 			wparam: 0,
@@ -712,7 +712,7 @@ impl MsgSendRecv for GetFont {
 }
 
 /// [`WM_GETHMENU`](https://docs.microsoft.com/en-us/windows/win32/winmsg/mn-gethmenu)
-/// message, which has no parameters.
+/// message, which has no parameters. Originally has `MN` prefix.
 ///
 /// Return type: `Option<HMENU>`.
 pub struct GetHMenu {}
@@ -721,10 +721,10 @@ impl MsgSend for GetHMenu {
 	type RetType = Option<HMENU>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		zero_as_none(v).map(|p| HMENU { ptr: p as _ })
+		zero_as_none(v).map(|p| HMENU(p as _))
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::MN_GETHMENU,
 			wparam: 0,
@@ -754,11 +754,11 @@ impl<'a> MsgSend for GetMinMaxInfo<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::GETMINMAXINFO,
 			wparam: 0,
-			lparam: self.info as *const _ as _,
+			lparam: self.info as *mut _ as _,
 		}
 	}
 }
@@ -771,6 +771,83 @@ impl<'a> MsgSendRecv for GetMinMaxInfo<'a> {
 	}
 }
 
+/// [`WM_GETTEXT`](https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-gettext)
+/// message parameters.
+///
+/// Return type: `u32`.
+///
+/// # Examples
+///
+/// ```rust,ignore
+/// use winsafe::{msg::wm, HWND, WString};
+///
+/// let hwnd: HWND; // initialized somewhere
+///
+/// let needed_len = hwnd.SendMessage(wm::GetTextLength {});
+/// let mut buf = WString::new_alloc_buffer(needed_len as _);
+///
+/// hwnd.SendMessage(wm::GetText {
+///     buffer: buf.as_mut_slice(),
+/// });
+///
+/// println!("Text: {}", buf.to_string());
+/// ```
+pub struct GetText<'a> {
+	pub buffer: &'a mut [u16], // can't be WString because this message can be received
+}
+
+impl<'a> MsgSend for GetText<'a> {
+	type RetType = u32;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		v as _
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::WM::GETTEXT,
+			wparam: self.buffer.len(),
+			lparam: self.buffer.as_mut_ptr() as _,
+		}
+	}
+}
+
+impl<'a> MsgSendRecv for GetText<'a> {
+	fn from_generic_wm(p: WndMsg) -> Self {
+		Self {
+			buffer: unsafe { std::slice::from_raw_parts_mut(p.lparam as _, p.wparam) },
+		}
+	}
+}
+
+/// [`WM_GETTEXTLENGTH`](https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-gettextlength)
+/// message, which has no parameters.
+///
+/// Return type: `u32`.
+pub struct GetTextLength {}
+
+impl MsgSend for GetTextLength {
+	type RetType = u32;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		v as _
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::WM::GETTEXTLENGTH,
+			wparam: 0,
+			lparam: 0,
+		}
+	}
+}
+
+impl MsgSendRecv for GetTextLength {
+	fn from_generic_wm(_: WndMsg) -> Self {
+		Self {}
+	}
+}
+
 /// [`WM_GETTITLEBARINFOEX`](https://docs.microsoft.com/en-us/windows/win32/menurc/wm-gettitlebarinfoex)
 /// message parameters.
 ///
@@ -786,11 +863,11 @@ impl<'a> MsgSend for GetTitleBarInfoEx<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::GETTITLEBARINFOEX,
 			wparam: 0,
-			lparam: self.info as *const _ as _,
+			lparam: self.info as *mut _ as _,
 		}
 	}
 }
@@ -818,7 +895,7 @@ impl<'a> MsgSend for Help<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::HELP,
 			wparam: 0,
@@ -852,11 +929,11 @@ impl MsgSend for HScroll {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::HSCROLL,
 			wparam: MAKEDWORD(self.request.0, self.scroll_box_pos) as _,
-			lparam: self.hcontrol.map(|h| h.ptr as _).unwrap_or_default(),
+			lparam: self.hcontrol.map(|h| h.0 as _).unwrap_or_default(),
 		}
 	}
 }
@@ -868,7 +945,7 @@ impl MsgSendRecv for HScroll {
 			request: co::SB_REQ(LOWORD(p.wparam as _)),
 			hcontrol: match p.lparam {
 				0 => None,
-				ptr => Some(HWND { ptr: ptr as _ }),
+				ptr => Some(HWND(ptr as _)),
 			},
 		}
 	}
@@ -890,10 +967,10 @@ impl MsgSend for InitDialog {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::INITDIALOG,
-			wparam: self.hwnd_focus.ptr as _,
+			wparam: self.hwnd_focus.0 as _,
 			lparam: self.additional_data,
 		}
 	}
@@ -902,7 +979,7 @@ impl MsgSend for InitDialog {
 impl MsgSendRecv for InitDialog {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hwnd_focus: HWND { ptr: p.wparam as _ },
+			hwnd_focus: HWND(p.wparam as _),
 			additional_data: p.lparam,
 		}
 	}
@@ -925,10 +1002,10 @@ impl MsgSend for InitMenuPopup {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::INITMENUPOPUP,
-			wparam: self.hmenu.ptr as _,
+			wparam: self.hmenu.0 as _,
 			lparam: MAKEDWORD(self.item_pos, self.is_window_menu as _) as _,
 		}
 	}
@@ -937,7 +1014,7 @@ impl MsgSend for InitMenuPopup {
 impl MsgSendRecv for InitMenuPopup {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hmenu: HMENU { ptr: p.wparam as _ },
+			hmenu: HMENU(p.wparam as _),
 			item_pos: LOWORD(p.lparam as _),
 			is_window_menu: HIWORD(p.lparam as _) != 0,
 		}
@@ -967,10 +1044,10 @@ impl MsgSend for KillFocus {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::KILLFOCUS,
-			wparam: self.hwnd.map(|h| h.ptr as _).unwrap_or_default(),
+			wparam: self.hwnd.map_or(0, |h| h.0 as _),
 			lparam: 0,
 		}
 	}
@@ -981,7 +1058,7 @@ impl MsgSendRecv for KillFocus {
 		Self {
 			hwnd: match p.wparam {
 				0 => None,
-				ptr => Some(HWND { ptr: ptr as _ }),
+				ptr => Some(HWND(ptr as _)),
 			},
 		}
 	}
@@ -1027,11 +1104,11 @@ impl MsgSend for MenuCommand {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::MENUCOMMAND,
 			wparam: self.item_index as _,
-			lparam: self.hmenu.ptr as _,
+			lparam: self.hmenu.0 as _,
 		}
 	}
 }
@@ -1040,7 +1117,7 @@ impl MsgSendRecv for MenuCommand {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
 			item_index: p.wparam as _,
-			hmenu: HMENU { ptr: p.lparam as _ },
+			hmenu: HMENU(p.lparam as _),
 		}
 	}
 }
@@ -1061,11 +1138,11 @@ impl MsgSend for MenuDrag {
 		co::MND(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::MENUDRAG,
 			wparam: self.position as _,
-			lparam: self.hmenu.ptr as _,
+			lparam: self.hmenu.0 as _,
 		}
 	}
 }
@@ -1074,7 +1151,7 @@ impl MsgSendRecv for MenuDrag {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
 			position: p.wparam as _,
-			hmenu: HMENU { ptr: p.lparam as _ },
+			hmenu: HMENU(p.lparam as _),
 		}
 	}
 }
@@ -1095,11 +1172,11 @@ impl MsgSend for MenuRButtonUp {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::MENURBUTTONUP,
 			wparam: self.position as _,
-			lparam: self.hmenu.ptr as _,
+			lparam: self.hmenu.0 as _,
 		}
 	}
 }
@@ -1108,7 +1185,7 @@ impl MsgSendRecv for MenuRButtonUp {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
 			position: p.wparam as _,
-			hmenu: HMENU { ptr: p.lparam as _ },
+			hmenu: HMENU(p.lparam as _),
 		}
 	}
 }
@@ -1140,7 +1217,7 @@ impl MsgSend for Move {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::MOVE,
 			wparam: 0,
@@ -1172,11 +1249,11 @@ impl<'a> MsgSend for Moving<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::MOVING,
 			wparam: 0,
-			lparam: self.window_pos as *const _ as _,
+			lparam: self.window_pos as *mut _ as _,
 		}
 	}
 }
@@ -1204,7 +1281,7 @@ impl<'a, 'b> MsgSend for NcCalcSize<'a, 'b> {
 		co::WVR(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::NCCALCSIZE,
 			wparam: match &self.data {
@@ -1245,7 +1322,7 @@ impl<'a, 'b, 'c> MsgSend for NcCreate<'a, 'b, 'c> {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::NCCREATE,
 			wparam: 0,
@@ -1281,7 +1358,7 @@ impl MsgSend for NcHitTest {
 		co::HT(v as _)
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::NCHITTEST,
 			wparam: 0,
@@ -1313,10 +1390,10 @@ impl MsgSend for NcPaint {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::NCPAINT,
-			wparam: self.updated_hrgn.ptr as _,
+			wparam: self.updated_hrgn.0 as _,
 			lparam: 0,
 		}
 	}
@@ -1325,7 +1402,7 @@ impl MsgSend for NcPaint {
 impl MsgSendRecv for NcPaint {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			updated_hrgn: HRGN { ptr: p.wparam as _ },
+			updated_hrgn: HRGN(p.wparam as _),
 		}
 	}
 }
@@ -1345,11 +1422,11 @@ impl MsgSend for NextDlgCtl {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::NEXTDLGCTL,
 			wparam: match self.hwnd_focus {
-				HwndFocus::Hwnd(hctl) => hctl.ptr as _,
+				HwndFocus::Hwnd(hctl) => hctl.0 as _,
 				HwndFocus::FocusNext(next) => if next { 0 } else { 1 },
 			},
 			lparam: MAKEDWORD(match self.hwnd_focus {
@@ -1364,7 +1441,7 @@ impl MsgSendRecv for NextDlgCtl {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
 			hwnd_focus: match p.wparam {
-				1 => HwndFocus::Hwnd(HWND { ptr: p.wparam as _ }),
+				1 => HwndFocus::Hwnd(HWND(p.wparam as _)),
 				_ => HwndFocus::FocusNext(p.wparam == 0),
 			},
 		}
@@ -1391,10 +1468,10 @@ impl<'a> MsgSend for Notify<'a> {
 		v
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::NOTIFY,
-			wparam: self.nmhdr.hwndFrom.ptr as _,
+			wparam: self.nmhdr.hwndFrom.0 as _,
 			lparam: self.nmhdr as *const _ as _,
 		}
 	}
@@ -1447,7 +1524,7 @@ impl MsgSend for ParentNotify {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::PARENTNOTIFY,
 			wparam: MAKEDWORD(self.event.0, self.child_id) as _,
@@ -1463,7 +1540,7 @@ impl MsgSendRecv for ParentNotify {
 			event,
 			child_id: HIWORD(p.wparam as _),
 			data: match event {
-				co::WMPN::CREATE | co::WMPN::DESTROY => HwndPointId::Hwnd(HWND { ptr: p.lparam as _ }),
+				co::WMPN::CREATE | co::WMPN::DESTROY => HwndPointId::Hwnd(HWND(p.lparam as _)),
 				co::WMPN::POINTERDOWN => HwndPointId::Id(p.lparam as _),
 				_ => HwndPointId::Point(lp_to_point(p)),
 			},
@@ -1484,7 +1561,7 @@ impl MsgSend for QueryOpen {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::QUERYOPEN,
 			wparam: 0,
@@ -1528,10 +1605,10 @@ impl MsgSend for SetCursor {
 		v != 0
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::SETCURSOR,
-			wparam: self.hwnd.ptr as _,
+			wparam: self.hwnd.0 as _,
 			lparam: MAKEDWORD(self.hit_test.0, self.mouse_msg) as _,
 		}
 	}
@@ -1540,7 +1617,7 @@ impl MsgSend for SetCursor {
 impl MsgSendRecv for SetCursor {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hwnd: HWND { ptr: p.wparam as _ },
+			hwnd: HWND(p.wparam as _),
 			hit_test: co::HT(LOWORD(p.lparam as _)),
 			mouse_msg: HIWORD(p.lparam as _),
 		}
@@ -1562,10 +1639,10 @@ impl MsgSend for SetFocus {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::SETFOCUS,
-			wparam: self.hwnd_losing_focus.ptr as _,
+			wparam: self.hwnd_losing_focus.0 as _,
 			lparam: 0,
 		}
 	}
@@ -1574,7 +1651,7 @@ impl MsgSend for SetFocus {
 impl MsgSendRecv for SetFocus {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hwnd_losing_focus: HWND { ptr: p.wparam as _ },
+			hwnd_losing_focus: HWND(p.wparam as _),
 		}
 	}
 }
@@ -1595,10 +1672,10 @@ impl MsgSend for SetFont {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::SETFONT,
-			wparam: self.hfont.ptr as _,
+			wparam: self.hfont.0 as _,
 			lparam: MAKEDWORD(self.redraw as _, 0) as _,
 		}
 	}
@@ -1607,7 +1684,7 @@ impl MsgSend for SetFont {
 impl MsgSendRecv for SetFont {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hfont: HFONT { ptr: p.wparam as _ },
+			hfont: HFONT(p.wparam as _),
 			redraw: LOWORD(p.lparam as _) != 0,
 		}
 	}
@@ -1626,14 +1703,14 @@ impl MsgSend for SetIcon {
 	type RetType = Option<HICON>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		zero_as_none(v).map(|p| HICON { ptr: p as _ })
+		zero_as_none(v).map(|p| HICON(p as _))
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::SETICON,
 			wparam: self.size.0 as _,
-			lparam: self.hicon.ptr as _,
+			lparam: self.hicon.0 as _,
 		}
 	}
 }
@@ -1642,7 +1719,7 @@ impl MsgSendRecv for SetIcon {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
 			size: co::ICON_SZ(p.wparam as _),
-			hicon: HICON { ptr: p.lparam as _ },
+			hicon: HICON(p.lparam as _),
 		}
 	}
 }
@@ -1662,7 +1739,7 @@ impl MsgSend for SetRedraw {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::SETREDRAW,
 			wparam: self.can_redraw as _,
@@ -1679,6 +1756,55 @@ impl MsgSendRecv for SetRedraw {
 	}
 }
 
+/// [`WM_SETTEXT`](https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-settext)
+/// message parameters.
+///
+/// Return type: `bool`.
+///
+/// # Examples
+///
+/// ```rust,ignore
+/// use winsafe::{msg::wm, HWND, WString};
+///
+/// let hwnd: HWND; // initialized somewhere
+///
+/// let new_text = WString::from_str("some text");
+///
+/// hwnd.SendMessage(wm::SetText {
+///     text: unsafe { new_text.as_ptr() },
+/// });
+/// ```
+pub struct SetText {
+	pub text: *const u16, // can't be WString because this message can be received
+}
+
+impl MsgSend for SetText {
+	type RetType = bool;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v as i32 {
+			0 | LB_ERRSPACE | CB_ERR => false, // CB_ERRSPACE is equal to LB_ERRSPACE
+			_ => true,
+		}
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::WM::SETTEXT,
+			wparam: 0,
+			lparam: self.text as _,
+		}
+	}
+}
+
+impl MsgSendRecv for SetText {
+	fn from_generic_wm(p: WndMsg) -> Self {
+		Self {
+			text: p.lparam as _,
+		}
+	}
+}
+
 /// [`WM_SHOWWINDOW`](https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-showwindow)
 /// message parameters.
 ///
@@ -1695,7 +1821,7 @@ impl MsgSend for ShowWindow {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::SHOWWINDOW,
 			wparam: self.being_shown as _,
@@ -1729,7 +1855,7 @@ impl MsgSend for Size {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::SIZE,
 			wparam: self.request.0 as _,
@@ -1769,11 +1895,11 @@ impl<'a> MsgSend for Sizing<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::SIZING,
 			wparam: self.window_edge.0 as _,
-			lparam: self.coords as *const _ as _,
+			lparam: self.coords as *mut _ as _,
 		}
 	}
 }
@@ -1803,7 +1929,7 @@ impl<'a> MsgSend for StyleChanged<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::STYLECHANGED,
 			wparam: self.change.0 as _,
@@ -1838,7 +1964,7 @@ impl<'a> MsgSend for StyleChanging<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::STYLECHANGING,
 			wparam: self.change.0 as _,
@@ -1881,7 +2007,7 @@ impl MsgSend for SysCommand {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::SYSCOMMAND,
 			wparam: self.request.0 as _,
@@ -1931,14 +2057,11 @@ impl MsgSend for Timer {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::TIMER,
 			wparam: self.timer_id as _,
-			lparam: match self.timer_proc {
-				Some(proc) => proc as _,
-				None => 0,
-			},
+			lparam: self.timer_proc.map_or(0, |proc| proc as _),
 		}
 	}
 }
@@ -1971,10 +2094,10 @@ impl MsgSend for UninitMenuPopup {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::UNINITMENUPOPUP,
-			wparam: self.hmenu.ptr as _,
+			wparam: self.hmenu.0 as _,
 			lparam: MAKEDWORD(0, self.which.0 as _) as _,
 		}
 	}
@@ -1983,12 +2106,40 @@ impl MsgSend for UninitMenuPopup {
 impl MsgSendRecv for UninitMenuPopup {
 	fn from_generic_wm(p: WndMsg) -> Self {
 		Self {
-			hmenu: HMENU { ptr: p.wparam as _ },
+			hmenu: HMENU(p.wparam as _),
 			which: co::MF(LOWORD(p.lparam as _) as _),
 		}
 	}
 }
 
+/// [`WM_UNDO`](https://docs.microsoft.com/en-us/windows/win32/controls/wm-undo)
+/// message, which has no parameters.
+///
+/// Return type: `bool`.
+pub struct Undo {}
+
+impl MsgSend for Undo {
+	type RetType = bool;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		v != 0
+	}
+
+	fn as_generic_wm(&mut self) -> WndMsg {
+		WndMsg {
+			msg_id: co::WM::UNDO,
+			wparam: 0,
+			lparam: 0,
+		}
+	}
+}
+
+impl MsgSendRecv for Undo {
+	fn from_generic_wm(_: WndMsg) -> Self {
+		Self {}
+	}
+}
+
 /// [`WM_VSCROLL`](https://docs.microsoft.com/en-us/windows/win32/controls/wm-vscroll)
 /// message parameters.
 ///
@@ -2006,11 +2157,11 @@ impl MsgSend for VScroll {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::VSCROLL,
 			wparam: MAKEDWORD(self.request.0, self.scroll_box_pos) as _,
-			lparam: self.hcontrol.map(|h| h.ptr as _).unwrap_or_default(),
+			lparam: self.hcontrol.map_or(0, |h| h.0 as _),
 		}
 	}
 }
@@ -2022,7 +2173,7 @@ impl MsgSendRecv for VScroll {
 			request: co::SB_REQ(LOWORD(p.wparam as _)),
 			hcontrol: match p.lparam {
 				0 => None,
-				ptr => Some(HWND { ptr: ptr as _ }),
+				ptr => Some(HWND(ptr as _)),
 			},
 		}
 	}
@@ -2043,7 +2194,7 @@ impl<'a> MsgSend for WindowPosChanged<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::WINDOWPOSCHANGED,
 			wparam: 0,
@@ -2075,7 +2226,7 @@ impl<'a> MsgSend for WindowPosChanging<'a> {
 		()
 	}
 
-	fn as_generic_wm(&self) -> WndMsg {
+	fn as_generic_wm(&mut self) -> WndMsg {
 		WndMsg {
 			msg_id: co::WM::WINDOWPOSCHANGING,
 			wparam: 0,
