@@ -467,6 +467,26 @@ pub struct DRAWITEMSTRUCT {
 
 impl_default!(DRAWITEMSTRUCT);
 
+/// [`EDITBALLOONTIP`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-editballoontip)
+/// struct.
+#[repr(C)]
+pub struct EDITBALLOONTIP<'a, 'b> {
+	cbStruct: u32,
+	pszTitle: *mut u16,
+	pszText: *mut u16,
+	pub ttiIcon: co::TTI,
+
+	pszTitle_: PhantomData<&'a mut u16>,
+	pszText_: PhantomData<&'b mut u16>,
+}
+
+impl_default_with_size!(EDITBALLOONTIP, cbStruct, 'a, 'b);
+
+impl<'a, 'b> EDITBALLOONTIP<'a, 'b> {
+	pub_fn_string_ptr_get_set!('a, pszTitle, set_pszTitle);
+	pub_fn_string_ptr_get_set!('b, pszText, set_pszText);
+}
+
 /// [`FILETIME`](https://docs.microsoft.com/en-us/windows/win32/api/minwinbase/ns-minwinbase-filetime)
 /// struct.
 #[repr(C)]
@@ -510,8 +530,8 @@ pub struct HELPINFO {
 impl HELPINFO {
 	pub fn hItemHandle(&self) -> HwndHmenu {
 		match self.iContextType {
-			co::HELPINFO::WINDOW => HwndHmenu::Hwnd(HWND { ptr: self.hItemHandle as _ }),
-			_ => HwndHmenu::Hmenu(HMENU { ptr: self.hItemHandle as _ }),
+			co::HELPINFO::WINDOW => HwndHmenu::Hwnd(HWND(self.hItemHandle as _)),
+			_ => HwndHmenu::Hmenu(HMENU(self.hItemHandle as _)),
 		}
 	}
 }
@@ -903,7 +923,6 @@ impl_default!(PROCESS_INFORMATION);
 
 /// [`PROCESSENTRY32`](https://docs.microsoft.com/en-us/windows/win32/api/tlhelp32/ns-tlhelp32-processentry32w)
 /// struct.
-#[allow(dead_code)]
 #[repr(C)]
 pub struct PROCESSENTRY32 {
 	dwSize: u32,
@@ -1249,7 +1268,7 @@ pub struct TASKDIALOGCONFIG<'a, 'b, 'c, 'd, 'e, 'f, 'g, 'h, 'i, 'j> {
 	pszContent: *mut u16,
 	cButtons: u32,
 	pButtons: *mut TASKDIALOG_BUTTON<'d>,
-	pub nDefaultButton: i32,
+	pub nDefaultButton: i32, // actually co::DLGID, which is u16
 	cRadioButtons: u32,
 	pRadioButtons: *mut TASKDIALOG_BUTTON<'e>,
 	pub nDefaultRadioButton: i32,
@@ -1291,7 +1310,7 @@ impl<'a, 'b, 'c, 'd, 'e, 'f, 'g, 'h, 'i, 'j>
 				IconIdTdicon::Id(self.pszMainIcon as _)
 			}
 		} else {
-			IconIdTdicon::Icon(HICON { ptr: self.pszMainIcon as _ })
+			IconIdTdicon::Icon(HICON(self.pszMainIcon as _))
 		}
 	}
 
@@ -1299,7 +1318,7 @@ impl<'a, 'b, 'c, 'd, 'e, 'f, 'g, 'h, 'i, 'j>
 	pub fn set_pszMainIcon(&mut self, val: IconIdTdicon) {
 		match val {
 			IconIdTdicon::None => self.pszMainIcon = std::ptr::null_mut(),
-			IconIdTdicon::Icon(hicon) => self.pszMainIcon = hicon.ptr as _,
+			IconIdTdicon::Icon(hicon) => self.pszMainIcon = hicon.0 as _,
 			IconIdTdicon::Id(id) => self.pszMainIcon = MAKEINTRESOURCE(id as _),
 			IconIdTdicon::Tdicon(tdi) => self.pszMainIcon = MAKEINTRESOURCE(tdi.0 as _),
 		}
@@ -1319,7 +1338,7 @@ impl<'a, 'b, 'c, 'd, 'e, 'f, 'g, 'h, 'i, 'j>
 		if IS_INTRESOURCE(self.pszFooterIcon) {
 			IconId::Id(self.pszFooterIcon as _)
 		} else {
-			IconId::Icon(HICON { ptr: self.pszFooterIcon as _ })
+			IconId::Icon(HICON(self.pszFooterIcon as _))
 		}
 	}
 
@@ -1327,7 +1346,7 @@ impl<'a, 'b, 'c, 'd, 'e, 'f, 'g, 'h, 'i, 'j>
 	pub fn set_pszFooterIcon(&mut self, val: IconId) {
 		match val {
 			IconId::None => self.pszFooterIcon = std::ptr::null_mut(),
-			IconId::Icon(hicon) => self.pszFooterIcon = hicon.ptr as _,
+			IconId::Icon(hicon) => self.pszFooterIcon = hicon.0 as _,
 			IconId::Id(id) => self.pszFooterIcon = MAKEINTRESOURCE(id as _),
 		}
 	}
@@ -1550,14 +1569,14 @@ impl WINDOWPOS {
 	pub fn hwndInsertAfter(&self) -> HwndPlace {
 		match self.hwndInsertAfter {
 			0 | 1 | -1 | -2 => HwndPlace::Place(co::HWND_PLACE(self.hwndInsertAfter)),
-			_ => HwndPlace::Hwnd(HWND { ptr: self.hwndInsertAfter as _ }),
+			_ => HwndPlace::Hwnd(HWND(self.hwndInsertAfter as _)),
 		}
 	}
 
 	/// Sets the `hwndInsertAfter` field.
 	pub fn set_hwndInsertAfter(&mut self, hwnd: HwndPlace) {
 		self.hwndInsertAfter = match hwnd {
-			HwndPlace::Hwnd(h) => h.ptr as _,
+			HwndPlace::Hwnd(h) => h.0 as _,
 			HwndPlace::Place(v) => v.into(),
 			HwndPlace::None => 0,
 		};
