@@ -7,13 +7,14 @@ use std::marker::PhantomData;
 use crate::co;
 use crate::enums::{BmpIdbRes, IdStr, IndexStr, TreeitemTvi};
 use crate::handles::{HBITMAP, HDC, HIMAGELIST, HINSTANCE, HTREEITEM, HWND};
+use crate::handles::prelude::Handle;
 use crate::privs::{
 	HINST_COMMCTRL,
 	IS_INTRESOURCE,
 	L_MAX_URL_LENGTH,
 	MAX_LINKID_TEXT,
 };
-use crate::structs::{COLORREF, NMHDR, POINT, RECT, SIZE, SYSTEMTIME};
+use crate::structs::{COLORREF, NMHDR, POINT, RECT, SIZE, SYSTEMTIME, WINDOWPOS};
 use crate::various::WString;
 
 /// [`BUTTON_IMAGELIST`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-button_imagelist)
@@ -51,6 +52,68 @@ pub struct DATETIMEPICKERINFO {
 
 impl_default_with_size!(DATETIMEPICKERINFO, cbSize);
 
+/// [`HDHITTESTINFO`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-hdhittestinfo)
+/// struct.
+#[repr(C)]
+#[derive(Default)]
+pub struct HDHITTESTINFO {
+	pub pt: POINT,
+	pub flags: co::HHT,
+	pub iItem: i32,
+}
+
+/// [`HDITEM`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-hditemw)
+/// struct.
+#[repr(C)]
+pub struct HDITEM<'a> {
+	pub mask: co::HDI,
+	pub cxy: i32,
+	pszText: *mut u16,
+	pub hbm: HBITMAP,
+	cchTextMax: i32,
+	pub fmt: co::HDF,
+	pub lParam: isize,
+	pub iImage: i32,
+	pub iOrder: i32,
+	pub typeFilter: co::HDFT,
+	pub pvFilter: *mut std::ffi::c_void,
+	pub state: co::HDIS,
+
+	pszText_: PhantomData<&'a mut u16>,
+}
+
+impl_default!(HDITEM, 'a);
+
+impl<'a> HDITEM<'a> {
+	pub_fn_string_buf_get_set!('a, pszText, set_pszText, cchTextMax);
+}
+
+/// [`HDLAYOUT`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-hdlayout)
+/// struct.
+#[repr(C)]
+pub struct HDLAYOUT<'a, 'b> {
+	prc: *mut RECT,
+	pwpos: *mut WINDOWPOS,
+	fuuu: i32,
+
+	prc_: PhantomData<&'a mut RECT>,
+	pwpos_: PhantomData<&'b mut WINDOWPOS>,
+}
+
+impl_default!(HDLAYOUT, 'a, 'b);
+
+impl<'a, 'b> HDLAYOUT<'a, 'b> {
+	/// Sets the field.
+	pub fn set_prc(&mut self, rc: Option<&'a mut RECT>) {
+		self.prc = rc.map(|rc| rc as _).unwrap_or(std::ptr::null_mut());
+	}
+
+	/// Sets the field.
+	pub fn set_pwpos(&mut self, pos: Option<&'b mut WINDOWPOS>) {
+		self.pwpos = pos.map(|pos| pos as _).unwrap_or(std::ptr::null_mut());
+	}
+}
+
 /// [`IMAGELISTDRAWPARAMS`](https://docs.microsoft.com/en-us/windows/win32/api/commoncontrols/ns-commoncontrols-imagelistdrawparams)
 /// struct.
 #[repr(C)]
@@ -621,7 +684,7 @@ impl TBADDBITMAP {
 	pub fn nID(&self) -> BmpIdbRes {
 		match self.hInst {
 			HINST_COMMCTRL => BmpIdbRes::Idb(co::IDB(self.nID)),
-			HINSTANCE::NULL => BmpIdbRes::Bmp(HBITMAP { ptr: self.nID as _ }),
+			HINSTANCE::NULL => BmpIdbRes::Bmp(HBITMAP(self.nID as _ )),
 			hInst => BmpIdbRes::Res(IdStr::from_ptr(self.nID as _), hInst),
 		}
 	}
@@ -630,7 +693,7 @@ impl TBADDBITMAP {
 	pub fn set_nID(&mut self, val: &BmpIdbRes) {
 		*self = match val {
 			BmpIdbRes::Idb(idb) => Self { hInst: HINST_COMMCTRL, nID: idb.0 },
-			BmpIdbRes::Bmp(bmp) => Self { hInst: HINSTANCE::NULL, nID: bmp.ptr as _ },
+			BmpIdbRes::Bmp(bmp) => Self { hInst: HINSTANCE::NULL, nID: bmp.0 as _ },
 			BmpIdbRes::Res(res, hInst) => Self { hInst: *hInst, nID: res.as_ptr() as _ },
 		}
 	}
