@@ -1,7 +1,7 @@
 use crate::aliases::WinResult;
 use crate::co;
-use crate::handles::HFILE;
-use crate::various::{MappedFile, MappedFileAccess, WString};
+use crate::handles::{prelude::HandleClose, HFILE};
+use crate::various::{FileAccess, FileMapped, WString};
 
 /// Keeps sections and key/value pairs of a `.ini` file, also doing parsing and
 /// serialization of the data.
@@ -21,7 +21,7 @@ use crate::various::{MappedFile, MappedFileAccess, WString};
 /// }
 /// ```
 pub struct Ini {
-	/// All the sections of the file.
+	/// All the sections of the file. The values can be modified at will.
 	pub sections: Vec<IniSection>,
 }
 
@@ -79,7 +79,9 @@ impl Ini {
 		Self { sections }
 	}
 
-	/// Parses an `Ini` from raw bytes.
+	/// Parses an `Ini` from raw bytes. The [`Encoding`](crate::Encoding) will
+	/// be guessed with
+	/// [`WString::guess_encoding`](crate::WString::guess_encoding).
 	pub fn parse_bytes(bytes: &[u8]) -> WinResult<Ini> {
 		Ok(
 			Self::parse_str(&WString::parse_str(bytes)?.to_string()),
@@ -88,7 +90,7 @@ impl Ini {
 
 	/// Parses an `Ini` directly from a file.
 	pub fn parse_from_file(ini_path: &str) -> WinResult<Ini> {
-		let fin = MappedFile::open(ini_path, MappedFileAccess::Read)?;
+		let fin = FileMapped::open(ini_path, FileAccess::ExistingReadOnly)?;
 		Self::parse_bytes(fin.as_slice())
 	}
 
@@ -125,7 +127,8 @@ impl Ini {
 		buf
 	}
 
-	/// Serializes the data to raw bytes.
+	/// Serializes the data to raw bytes with
+	/// [`String::into_bytes`](https://doc.rust-lang.org/std/string/struct.String.html#method.into_bytes).
 	pub fn serialize_to_bytes(&self) -> Vec<u8> {
 		self.serialize_to_str().into_bytes()
 	}
@@ -145,19 +148,19 @@ impl Ini {
 	pub fn value(&self, section: &str, key: &str) -> Option<&str> {
 		self.sections.iter()
 			.find(|s| s.name == section)
-			.map(|s| s.entries.iter()
+			.and_then(|s| s.entries.iter()
 				.find(|e| e.key == key)
 				.map(|e| e.val.as_ref())
-			).flatten()
+			)
 	}
 
 	/// Returns a mutable reference to the specified value, if any.
 	pub fn value_mut(&mut self, section: &str, key: &str) -> Option<&mut str> {
 		self.sections.iter_mut()
 			.find(|s| s.name == section)
-			.map(|s| s.entries.iter_mut()
+			.and_then(|s| s.entries.iter_mut()
 				.find(|e| e.key == key)
 				.map(|e| e.val.as_mut())
-			).flatten()
+			)
 	}
 }
